@charset "UTF-8";
/* king-vertical-nav4*/
.king-vertical-nav4 {
  min-width: 160px;
  min-height: 100%;
  margin: 0;
  border-right: 1px solid #dddddd;
  background-color: #f2f2f2;
  z-index: 10; }
  .king-vertical-nav4.king-full-height {
    position: fixed;
    min-height: 100%;
    margin: 0;
    z-index: 10; }
  .king-vertical-nav4.auto-height {
    position: absolute;
    min-height: 100%;
    width: 100%;
    margin: 0;
    z-index: 10; }
  .king-vertical-nav4 .navbar-header {
    float: none;
    background: #4a9bff; }
    .king-vertical-nav4 .navbar-header a {
      color: #fff;
      font-weight: 400; }
  .king-vertical-nav4 ul {
    text-align: left;
    padding: 0;
    margin: 0;
    list-style-type: none; }
    .king-vertical-nav4 ul li {
      list-style-type: none; }
  .king-vertical-nav4 .sidebar-inner {
    display: block;
    width: 100%;
    margin: 0 auto;
    position: relative;
    z-index: 60; }
  .king-vertical-nav4 .sidebar-search {
    padding: 10px; }
    .king-vertical-nav4 .sidebar-search input {
      border-color: #eee;
      box-shadow: none;
      border-radius: 0; }
      .king-vertical-nav4 .sidebar-search input:focus {
        border-color: #4a9bff; }
  .king-vertical-nav4 .navi li i {
    margin-right: 5px; }
  .king-vertical-nav4 .navi li span i {
    margin: 0px; }
  .king-vertical-nav4 .navi li ul {
    display: none;
    background: #eee;
    padding: 5px 0 10px 0;
    background-color: transparent;
    border-top: 1px solid #f5f5f5;
    border-bottom: 1px solid #dbdbdb; }
  .king-vertical-nav4 .navi li > a {
    padding: 10px 20px;
    font-size: 14px;
    border-top: none;
    border-bottom: 1px solid #e8e8e8; }
  .king-vertical-nav4 .navi li.last ul {
    border-bottom: none; }
  .king-vertical-nav4 .navi > li.active > a {
    background-color: #eee;
    color: #000; }
  .king-vertical-nav4 .navi > li > a {
    display: block;
    padding: 12px 20px;
    font-size: 15px;
    line-height: 25px;
    color: #555;
    text-decoration: none;
    border-top: 1px solid #eaeaea; }
    .king-vertical-nav4 .navi > li > a:hover {
      background-color: #eee;
      color: #000; }
  .king-vertical-nav4 .navi .open ul {
    display: block; }
  .king-vertical-nav4 .navi i.fa {
    margin-right: 14px;
    font-size: 22px;
    vertical-align: sub; }
  .king-vertical-nav4 .navi i.fa-tasks {
    font-size: 20px; }
  .king-vertical-nav4 .navi i.fa-angle-down {
    font-size: 16px;
    margin-right: 0px; }
  .king-vertical-nav4 .navi .sub-menu i {
    display: none;
    font-size: 12px;
    margin-top: 11px;
    margin-right: 20px; }
  .king-vertical-nav4 .navi .sub-menu li {
    display: block;
    padding-left: 53px;
    border-top: none;
    line-height: 32px; }
    .king-vertical-nav4 .navi .sub-menu li a {
      color: #777;
      padding: 0px;
      font-size: 12px; }
      .king-vertical-nav4 .navi .sub-menu li a:hover {
        color: #266cad; }
    .king-vertical-nav4 .navi .sub-menu li.active a {
      color: #266cad; }
    .king-vertical-nav4 .navi .sub-menu li.active i {
      display: block; }
  .king-vertical-nav4 .sidebar .navi > li.open > a {
    background-color: #eee;
    color: #000; }

/* king-vertical-nav5*/
.king-vertical-nav5 {
  text-align: left;
  background: #f5f5f5;
  position: relative;
  min-width: 200px;
  z-index: 999;
  overflow: hidden; }
  .king-vertical-nav5.king-full-height {
    position: fixed;
    min-height: 100%;
    margin: 0;
    z-index: 10; }
  .king-vertical-nav5 .sidebar {
    margin: 0;
    text-indent: 20px;
    list-style: none;
    padding: 0; }
    .king-vertical-nav5 .sidebar li a {
      color: #fff;
      display: block;
      float: left;
      text-decoration: none;
      width: 100%; }
    .king-vertical-nav5 .sidebar .sidebar-main {
      height: 65px; }
      .king-vertical-nav5 .sidebar .sidebar-main a {
        font-size: 18px;
        line-height: 60px;
        background: #4A9BFF; }
      .king-vertical-nav5 .sidebar .sidebar-main .menu-icon {
        float: right;
        margin-top: 23px;
        margin-right: 28px; }
    .king-vertical-nav5 .sidebar .sidebar-title {
      font-size: 15px;
      height: 35px;
      line-height: 40px;
      text-transform: uppercase;
      color: #333; }
    .king-vertical-nav5 .sidebar .sidebar-item {
      height: 40px; }
      .king-vertical-nav5 .sidebar .sidebar-item a {
        color: #666;
        border-left: 3px solid #f5f5f5;
        font-size: 12px;
        line-height: 40px;
        text-indent: 25px; }
        .king-vertical-nav5 .sidebar .sidebar-item a:hover {
          background: #eee;
          color: #000;
          border-color: #4A9BFF; }
          .king-vertical-nav5 .sidebar .sidebar-item a:hover .menu-icon {
            text-indent: 25px; }
      .king-vertical-nav5 .sidebar .sidebar-item .menu-icon {
        float: right;
        margin-top: 13px;
        margin-right: 29px; }
      .king-vertical-nav5 .sidebar .sidebar-item.current a {
        border-color: #4A9BFF;
        background: #eee;
        color: #000; }

.king-vertical-nav5-warning .sidebar .sidebar-main a {
  background: #f3b760; }
.king-vertical-nav5-warning .sidebar .sidebar-item a:hover {
  border-color: #f3b760; }
.king-vertical-nav5-warning .sidebar .sidebar-item.current a {
  border-color: #f3b760; }

.king-vertical-nav5-danger .sidebar .sidebar-main a {
  background: #d26a5c; }
.king-vertical-nav5-danger .sidebar .sidebar-item a:hover {
  border-color: #d26a5c; }
.king-vertical-nav5-danger .sidebar .sidebar-item.current a {
  border-color: #d26a5c; }

.king-vertical-nav5-success .sidebar .sidebar-main a {
  background: #44B549; }
.king-vertical-nav5-success .sidebar .sidebar-item a:hover {
  border-color: #44B549; }
.king-vertical-nav5-success .sidebar .sidebar-item.current a {
  border-color: #44B549; }

/* king-vertical-nav6*/
.king-vertical-nav6 {
  z-index: 9;
  height: 100%;
  background: #e1e1e1;
  background: #f2f2f2; }
  .king-vertical-nav6.king-full-height {
    position: fixed;
    min-height: 100%;
    margin: 0;
    z-index: 10; }
  .king-vertical-nav6 .nav-header {
    display: block;
    padding: 12px 20px;
    background: #4A9BFF;
    color: #fff;
    font-size: 24px;
    font-weight: bold; }
    .king-vertical-nav6 .nav-header .logo {
      font-size: 44px;
      vertical-align: middle;
      margin-right: 10px; }
  .king-vertical-nav6 .nav-list {
    list-style: none;
    margin: auto;
    padding: 0; }
    .king-vertical-nav6 .nav-list .fa {
      font-size: 16px;
      margin-left: 20px; }
    .king-vertical-nav6 .nav-list li {
      height: 60px;
      line-height: 60px;
      text-align: left; }
      .king-vertical-nav6 .nav-list li a {
        display: block;
        font-size: 14px;
        color: #444; }
        .king-vertical-nav6 .nav-list li a:hover, .king-vertical-nav6 .nav-list li a.active {
          background: #fff; }
      .king-vertical-nav6 .nav-list li .sidebar_icon {
        display: block;
        width: 36px;
        height: 32px;
        float: left;
        margin: 15px 10px 0 20px;
        background: url(../images/sprite_sidebar.png) no-repeat; }
      .king-vertical-nav6 .nav-list li i.icon_business {
        background-position: 1px -13px; }
      .king-vertical-nav6 .nav-list li i.icon_knowledge {
        background-position: 1px -72px; }
      .king-vertical-nav6 .nav-list li i.icon_data {
        background-position: 1px -134px; }
      .king-vertical-nav6 .nav-list li i.icon_work {
        background-position: 1px -193px; }
      .king-vertical-nav6 .nav-list li i.icon_manage {
        background-position: 1px -254px; }
      .king-vertical-nav6 .nav-list li i.icon_devel {
        background-position: 1px -316px; }

/* king-vertical-nav9*/
.king-vertical-nav9 .navbar-nav > li {
  float: none; }
  .king-vertical-nav9 .navbar-nav > li > a {
    color: #eee; }
    .king-vertical-nav9 .navbar-nav > li > a:hover, .king-vertical-nav9 .navbar-nav > li > a:focus {
      background-color: #222C31; }
.king-vertical-nav9 .navbar-nav > .active > a, .king-vertical-nav9 .navbar-nav > .active > a:hover, .king-vertical-nav9 .navbar-nav > .active > a:focus {
  color: #fff;
  background-color: #162127; }
.king-vertical-nav9 .side-nav {
  background-color: #263238;
  float: none;
  margin-left: -215px;
  border: none;
  border-radius: 0;
  overflow-y: auto;
  background-color: #263238;
  bottom: 0;
  overflow-x: hidden;
  padding-bottom: 40px; }
  .king-vertical-nav9 .side-nav li a:hover, .king-vertical-nav9 .side-nav li a:focus {
    outline: none;
    background-color: #2D3D46; }
  .king-vertical-nav9 .side-nav > li > a {
    display: block; }
  .king-vertical-nav9 .side-nav > li > ul {
    padding: 0; }
    .king-vertical-nav9 .side-nav > li > ul > li > a {
      display: block;
      padding: 10px 15px 10px 38px;
      text-decoration: none;
      color: #999; }
      .king-vertical-nav9 .side-nav > li > ul > li > a:hover {
        color: #fff; }
.king-vertical-nav9 .navbar-collapse {
  padding-left: 215px;
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.05);
  padding-right: 0px; }
.king-vertical-nav9.king-full-height {
  position: fixed;
  min-height: 100%;
  margin: 0;
  z-index: 10;
  background-color: #263238; }

/* 纵向导航菜单样例十*/
.king-vertical-nav10 {
  width: 80px;
  background: #2a2b3c; }
  .king-vertical-nav10.king-full-height {
    height: 100%; }
  .king-vertical-nav10 .sidebar-inner {
    padding: 80px 0px 120px 0px; }
  .king-vertical-nav10 ul {
    text-align: left;
    padding: 0;
    margin: 0;
    list-style-type: none; }
  .king-vertical-nav10 .navi li a {
    display: block;
    width: 100%;
    height: 65px;
    padding-top: 13px;
    text-align: center;
    color: #fff;
    font-size: 12px;
    text-decoration: none; }
  .king-vertical-nav10 .navi > li {
    position: relative;
    border-bottom: #252636 1px solid; }
    .king-vertical-nav10 .navi > li:hover {
      background-color: #252636;
      border-bottom: #252636 1px solid; }
      .king-vertical-nav10 .navi > li:hover .sub-menu {
        display: block;
        z-index: 10; }
    .king-vertical-nav10 .navi > li.active, .king-vertical-nav10 .navi > li.active:hover {
      background-color: #a54e4c; }
    .king-vertical-nav10 .navi > li .fa {
      display: block;
      font-size: 20px;
      color: #fff; }
  .king-vertical-nav10 .navi .sub-menu {
    display: none;
    position: absolute;
    left: 80px;
    top: 0px;
    min-width: 200px;
    padding: 10px;
    background-color: #252636; }
    .king-vertical-nav10 .navi .sub-menu li {
      border: none;
      padding: 0;
      line-height: 40px; }
      .king-vertical-nav10 .navi .sub-menu li.active a {
        background-color: #a54e4c;
        color: #fff; }
      .king-vertical-nav10 .navi .sub-menu li a {
        position: relative;
        display: block;
        height: auto;
        line-height: 1em;
        padding: 8px 20px;
        color: #fff;
        white-space: nowrap;
        text-align: left; }
        .king-vertical-nav10 .navi .sub-menu li a:hover {
          background-color: #a54e4c;
          color: #fff; }
  .king-vertical-nav10 .navi .has-submenu > a {
    cursor: default; }

.king-vertical-info.king-vertical-nav10 {
  background-color: #177fff; }
  .king-vertical-info.king-vertical-nav10 .navi > li {
    border-bottom: #0071fd 1px solid; }
    .king-vertical-info.king-vertical-nav10 .navi > li:hover {
      background-color: #4A9BFF;
      border-bottom: #4A9BFF 1px solid; }
    .king-vertical-info.king-vertical-nav10 .navi > li.active, .king-vertical-info.king-vertical-nav10 .navi > li.active:hover {
      background-color: #4A9BFF; }
  .king-vertical-info.king-vertical-nav10 .navi .sub-menu {
    background-color: #4A9BFF; }
    .king-vertical-info.king-vertical-nav10 .navi .sub-menu li.active a {
      background-color: #177fff; }
    .king-vertical-info.king-vertical-nav10 .navi .sub-menu li a:hover {
      background-color: #177fff; }

.king-vertical-primary.king-vertical-nav10 {
  background-color: #3675c5; }
  .king-vertical-primary.king-vertical-nav10 .navi > li {
    border-bottom: #3169b1 1px solid; }
    .king-vertical-primary.king-vertical-nav10 .navi > li:hover {
      background-color: #5c90d2;
      border-bottom: #5c90d2 1px solid; }
    .king-vertical-primary.king-vertical-nav10 .navi > li.active, .king-vertical-primary.king-vertical-nav10 .navi > li.active:hover {
      background-color: #5c90d2; }
  .king-vertical-primary.king-vertical-nav10 .navi .sub-menu {
    background-color: #5c90d2; }
    .king-vertical-primary.king-vertical-nav10 .navi .sub-menu li.active a {
      background-color: #3675c5; }
    .king-vertical-primary.king-vertical-nav10 .navi .sub-menu li a:hover {
      background-color: #3675c5; }

.king-vertical-warning.king-vertical-nav10 {
  background-color: #efa231; }
  .king-vertical-warning.king-vertical-nav10 .navi > li {
    border-bottom: #ee9719 1px solid; }
    .king-vertical-warning.king-vertical-nav10 .navi > li:hover {
      background-color: #f3b760;
      border-bottom: #f3b760 1px solid; }
    .king-vertical-warning.king-vertical-nav10 .navi > li.active, .king-vertical-warning.king-vertical-nav10 .navi > li.active:hover {
      background-color: #f3b760; }
  .king-vertical-warning.king-vertical-nav10 .navi .sub-menu {
    background-color: #f3b760; }
    .king-vertical-warning.king-vertical-nav10 .navi .sub-menu li.active a {
      background-color: #efa231; }
    .king-vertical-warning.king-vertical-nav10 .navi .sub-menu li a:hover {
      background-color: #efa231; }

.king-vertical-danger.king-vertical-nav10 {
  background-color: #c54736; }
  .king-vertical-danger.king-vertical-nav10 .navi > li {
    border-bottom: #b14031 1px solid; }
    .king-vertical-danger.king-vertical-nav10 .navi > li:hover {
      background-color: #d26a5c;
      border-bottom: #d26a5c 1px solid; }
    .king-vertical-danger.king-vertical-nav10 .navi > li.active, .king-vertical-danger.king-vertical-nav10 .navi > li.active:hover {
      background-color: #d26a5c; }
  .king-vertical-danger.king-vertical-nav10 .navi .sub-menu {
    background-color: #d26a5c; }
    .king-vertical-danger.king-vertical-nav10 .navi .sub-menu li.active a {
      background-color: #c54736; }
    .king-vertical-danger.king-vertical-nav10 .navi .sub-menu li a:hover {
      background-color: #c54736; }

.king-vertical-success.king-vertical-nav10 {
  background-color: #36903a; }
  .king-vertical-success.king-vertical-nav10 .navi > li {
    border-bottom: #2f7d33 1px solid; }
    .king-vertical-success.king-vertical-nav10 .navi > li:hover {
      background-color: #44B549;
      border-bottom: #44B549 1px solid; }
    .king-vertical-success.king-vertical-nav10 .navi > li.active, .king-vertical-success.king-vertical-nav10 .navi > li.active:hover {
      background-color: #44B549; }
  .king-vertical-success.king-vertical-nav10 .navi .sub-menu {
    background-color: #44B549; }
    .king-vertical-success.king-vertical-nav10 .navi .sub-menu li.active a {
      background-color: #36903a; }
    .king-vertical-success.king-vertical-nav10 .navi .sub-menu li a:hover {
      background-color: #36903a; }

.king-vertical-nav10-info.king-vertical-nav10 {
  background-color: #177fff; }
  .king-vertical-nav10-info.king-vertical-nav10 .navi > li {
    border-bottom: #0071fd 1px solid; }
    .king-vertical-nav10-info.king-vertical-nav10 .navi > li:hover {
      background-color: #4A9BFF;
      border-bottom: #4A9BFF 1px solid; }
    .king-vertical-nav10-info.king-vertical-nav10 .navi > li.active, .king-vertical-nav10-info.king-vertical-nav10 .navi > li.active:hover {
      background-color: #4A9BFF; }
  .king-vertical-nav10-info.king-vertical-nav10 .navi .sub-menu {
    background-color: #4A9BFF; }
    .king-vertical-nav10-info.king-vertical-nav10 .navi .sub-menu li.active a {
      background-color: #177fff; }
    .king-vertical-nav10-info.king-vertical-nav10 .navi .sub-menu li a:hover {
      background-color: #177fff; }

.king-vertical-nav10-primary.king-vertical-nav10 {
  background-color: #3675c5; }
  .king-vertical-nav10-primary.king-vertical-nav10 .navi > li {
    border-bottom: #3169b1 1px solid; }
    .king-vertical-nav10-primary.king-vertical-nav10 .navi > li:hover {
      background-color: #5c90d2;
      border-bottom: #5c90d2 1px solid; }
    .king-vertical-nav10-primary.king-vertical-nav10 .navi > li.active, .king-vertical-nav10-primary.king-vertical-nav10 .navi > li.active:hover {
      background-color: #5c90d2; }
  .king-vertical-nav10-primary.king-vertical-nav10 .navi .sub-menu {
    background-color: #5c90d2; }
    .king-vertical-nav10-primary.king-vertical-nav10 .navi .sub-menu li.active a {
      background-color: #3675c5; }
    .king-vertical-nav10-primary.king-vertical-nav10 .navi .sub-menu li a:hover {
      background-color: #3675c5; }

.king-vertical-nav10-warning.king-vertical-nav10 {
  background-color: #efa231; }
  .king-vertical-nav10-warning.king-vertical-nav10 .navi > li {
    border-bottom: #ee9719 1px solid; }
    .king-vertical-nav10-warning.king-vertical-nav10 .navi > li:hover {
      background-color: #f3b760;
      border-bottom: #f3b760 1px solid; }
    .king-vertical-nav10-warning.king-vertical-nav10 .navi > li.active, .king-vertical-nav10-warning.king-vertical-nav10 .navi > li.active:hover {
      background-color: #f3b760; }
  .king-vertical-nav10-warning.king-vertical-nav10 .navi .sub-menu {
    background-color: #f3b760; }
    .king-vertical-nav10-warning.king-vertical-nav10 .navi .sub-menu li.active a {
      background-color: #efa231; }
    .king-vertical-nav10-warning.king-vertical-nav10 .navi .sub-menu li a:hover {
      background-color: #efa231; }

.king-vertical-nav10-danger.king-vertical-nav10 {
  background-color: #c54736; }
  .king-vertical-nav10-danger.king-vertical-nav10 .navi > li {
    border-bottom: #b14031 1px solid; }
    .king-vertical-nav10-danger.king-vertical-nav10 .navi > li:hover {
      background-color: #d26a5c;
      border-bottom: #d26a5c 1px solid; }
    .king-vertical-nav10-danger.king-vertical-nav10 .navi > li.active, .king-vertical-nav10-danger.king-vertical-nav10 .navi > li.active:hover {
      background-color: #d26a5c; }
  .king-vertical-nav10-danger.king-vertical-nav10 .navi .sub-menu {
    background-color: #d26a5c; }
    .king-vertical-nav10-danger.king-vertical-nav10 .navi .sub-menu li.active a {
      background-color: #c54736; }
    .king-vertical-nav10-danger.king-vertical-nav10 .navi .sub-menu li a:hover {
      background-color: #c54736; }

.king-vertical-nav10-success.king-vertical-nav10 {
  background-color: #36903a; }
  .king-vertical-nav10-success.king-vertical-nav10 .navi > li {
    border-bottom: #2f7d33 1px solid; }
    .king-vertical-nav10-success.king-vertical-nav10 .navi > li:hover {
      background-color: #44B549;
      border-bottom: #44B549 1px solid; }
    .king-vertical-nav10-success.king-vertical-nav10 .navi > li.active, .king-vertical-nav10-success.king-vertical-nav10 .navi > li.active:hover {
      background-color: #44B549; }
  .king-vertical-nav10-success.king-vertical-nav10 .navi .sub-menu {
    background-color: #44B549; }
    .king-vertical-nav10-success.king-vertical-nav10 .navi .sub-menu li.active a {
      background-color: #36903a; }
    .king-vertical-nav10-success.king-vertical-nav10 .navi .sub-menu li a:hover {
      background-color: #36903a; }

/* 横向导航一*/
.king-horizontal-nav1 {
  min-height: 45px;
  width: 100%;
  height: 45px;
  margin-bottom: 0px;
  background-color: #333;
  border-radius: 0px;
  border: none;
  line-height: 45px;
  z-index: 100; }
  .king-horizontal-nav1 .navbar-container {
    overflow: hidden; }
  .king-horizontal-nav1 .logo {
    height: 30px;
    margin-top: 8px; }
  .king-horizontal-nav1 .navbar-brand {
    width: 216px;
    height: 45px;
    padding: 0 0 0 18px;
    border-right: 1px solid #222222;
    line-height: 45px;
    font-size: 22px;
    color: #FFFFFF; }
    .king-horizontal-nav1 .navbar-brand h1 {
      display: inline;
      margin: 0px;
      padding: 0px;
      font-size: 22px;
      font-weight: 400;
      line-height: inherit; }
  .king-horizontal-nav1 .fa-leaf {
    margin-right: 6px;
    font-size: 24px; }
  .king-horizontal-nav1 .img-rounded {
    width: 30px;
    height: 30px;
    border-radius: 30px; }
  .king-horizontal-nav1 li a {
    padding: 0 18px 0 15px;
    height: 45px;
    line-height: 45px;
    display: inline-block;
    color: #FFF; }
  .king-horizontal-nav1 .nav > li img {
    margin-right: 6px; }
  .king-horizontal-nav1 .nav > li > a:hover, .king-horizontal-nav1 .nav > li > a:focus {
    background-color: #191818; }
  .king-horizontal-nav1 .nav > li.active a {
    background-color: #191818; }
  .king-horizontal-nav1 .product-select {
    width: 422px; }
  .king-horizontal-nav1 .product-select select {
    border-radius: 2px; }
  .king-horizontal-nav1 .product-select .control-label {
    float: left;
    width: 102px;
    color: #FFF;
    text-align: right; }
  .king-horizontal-nav1 .product-select .control-select {
    float: left;
    width: 320px; }

.king-horizontal-info.king-horizontal-nav1 {
  background-color: #4A9BFF; }
  .king-horizontal-info.king-horizontal-nav1 .navbar-brand {
    border-right: 1px solid #2180F5; }
  .king-horizontal-info.king-horizontal-nav1 .nav > li > a:hover, .king-horizontal-info.king-horizontal-nav1 .nav > li > a:focus {
    background-color: #177fff; }
  .king-horizontal-info.king-horizontal-nav1 .nav > li.active a {
    background-color: #177fff; }
  .king-horizontal-info.king-horizontal-nav1 li a {
    color: #fff; }

.king-horizontal-default.king-horizontal-nav1 {
  background-color: #f4f4f4; }
  .king-horizontal-default.king-horizontal-nav1 .navbar-brand {
    border-right: 1px solid #ddd; }
  .king-horizontal-default.king-horizontal-nav1 .nav > li > a:hover, .king-horizontal-default.king-horizontal-nav1 .nav > li > a:focus {
    background-color: #dbdbdb; }
  .king-horizontal-default.king-horizontal-nav1 .nav > li.active a {
    background-color: #dbdbdb; }
  .king-horizontal-default.king-horizontal-nav1 li a {
    color: #555; }

.king-horizontal-primary.king-horizontal-nav1 {
  background-color: #5c90d2; }
  .king-horizontal-primary.king-horizontal-nav1 .navbar-brand {
    border-right: 1px solid #3675c5; }
  .king-horizontal-primary.king-horizontal-nav1 .nav > li > a:hover, .king-horizontal-primary.king-horizontal-nav1 .nav > li > a:focus {
    background-color: #3675c5; }
  .king-horizontal-primary.king-horizontal-nav1 .nav > li.active a {
    background-color: #3675c5; }
  .king-horizontal-primary.king-horizontal-nav1 li a {
    color: #fff; }

.king-horizontal-warning.king-horizontal-nav1 {
  background-color: #f3b760; }
  .king-horizontal-warning.king-horizontal-nav1 .navbar-brand {
    border-right: 1px solid #efa231; }
  .king-horizontal-warning.king-horizontal-nav1 .nav > li > a:hover, .king-horizontal-warning.king-horizontal-nav1 .nav > li > a:focus {
    background-color: #efa231; }
  .king-horizontal-warning.king-horizontal-nav1 .nav > li.active a {
    background-color: #efa231; }
  .king-horizontal-warning.king-horizontal-nav1 li a {
    color: #fff; }

.king-horizontal-success.king-horizontal-nav1 {
  background-color: #44B549; }
  .king-horizontal-success.king-horizontal-nav1 .navbar-brand {
    border-right: 1px solid #34a263; }
  .king-horizontal-success.king-horizontal-nav1 .nav > li > a:hover, .king-horizontal-success.king-horizontal-nav1 .nav > li > a:focus {
    background-color: #34a263; }
  .king-horizontal-success.king-horizontal-nav1 .nav > li.active a {
    background-color: #34a263; }
  .king-horizontal-success.king-horizontal-nav1 li a {
    color: #fff; }

.king-horizontal-danger.king-horizontal-nav1 {
  background-color: #d26a5c; }
  .king-horizontal-danger.king-horizontal-nav1 .navbar-brand {
    border-right: 1px solid #c54736; }
  .king-horizontal-danger.king-horizontal-nav1 .nav > li > a:hover, .king-horizontal-danger.king-horizontal-nav1 .nav > li > a:focus {
    background-color: #c54736; }
  .king-horizontal-danger.king-horizontal-nav1 .nav > li.active a {
    background-color: #c54736; }
  .king-horizontal-danger.king-horizontal-nav1 li a {
    color: #fff; }

/* 横向导航菜单样例二*/
.king-horizontal-nav2 {
  border: 0;
  border-radius: 0;
  background: #fafafa;
  border-bottom: 1px solid #eee; }
  .king-horizontal-nav2 .navbar-header {
    height: 50px;
    margin-right: 20px; }
    .king-horizontal-nav2 .navbar-header .navbar-toggle {
      margin-top: 3px; }
  .king-horizontal-nav2 .navbar-nav {
    padding: 0 0 0 20px; }
    .king-horizontal-nav2 .navbar-nav li a {
      height: 50px;
      line-height: 50px;
      color: #555;
      padding: 0 15px; }
      .king-horizontal-nav2 .navbar-nav li a i {
        position: relative;
        top: 2px; }
      .king-horizontal-nav2 .navbar-nav li a:link, .king-horizontal-nav2 .navbar-nav li a:visited {
        color: #555; }
      .king-horizontal-nav2 .navbar-nav li a:hover, .king-horizontal-nav2 .navbar-nav li a:active {
        background: #4a9bff;
        color: #fff; }
        .king-horizontal-nav2 .navbar-nav li a:hover i, .king-horizontal-nav2 .navbar-nav li a:active i {
          background-image: url(../img/glyphicons-halflings.png); }
    .king-horizontal-nav2 .navbar-nav li.king-navbar-active a {
      background: #4a9bff;
      color: #fff; }
      .king-horizontal-nav2 .navbar-nav li.king-navbar-active a i {
        background-image: url(../img/glyphicons-halflings.png); }

@media (max-width: 768px) {
  .king-horizontal-nav2 .navbar-collapse {
    padding-left: 0; }

  .king-header2 .navbar-collapse {
    padding-left: 15px; } }
.king-horizontal-info.king-horizontal-nav2 .navbar-nav li a:hover, .king-horizontal-info.king-horizontal-nav2 .navbar-nav li a:active {
  background: #4A9BFF;
  color: #fff; }
.king-horizontal-info.king-horizontal-nav2 .navbar-nav li.king-navbar-active a {
  background: #4A9BFF;
  color: #fff; }

.king-horizontal-default.king-horizontal-nav2 .navbar-nav li a:hover, .king-horizontal-default.king-horizontal-nav2 .navbar-nav li a:active {
  background: #f4f4f4;
  color: #555; }
.king-horizontal-default.king-horizontal-nav2 .navbar-nav li.king-navbar-active a {
  background: #f4f4f4;
  color: #555; }

.king-horizontal-primary.king-horizontal-nav2 .navbar-nav li a:hover, .king-horizontal-primary.king-horizontal-nav2 .navbar-nav li a:active {
  background: #5c90d2;
  color: #fff; }
.king-horizontal-primary.king-horizontal-nav2 .navbar-nav li.king-navbar-active a {
  background: #5c90d2;
  color: #fff; }

.king-horizontal-warning.king-horizontal-nav2 .navbar-nav li a:hover, .king-horizontal-warning.king-horizontal-nav2 .navbar-nav li a:active {
  background: #f3b760;
  color: #fff; }
.king-horizontal-warning.king-horizontal-nav2 .navbar-nav li.king-navbar-active a {
  background: #f3b760;
  color: #fff; }

.king-horizontal-success.king-horizontal-nav2 .navbar-nav li a:hover, .king-horizontal-success.king-horizontal-nav2 .navbar-nav li a:active {
  background: #44B549;
  color: #fff; }
.king-horizontal-success.king-horizontal-nav2 .navbar-nav li.king-navbar-active a {
  background: #44B549;
  color: #fff; }

.king-horizontal-danger.king-horizontal-nav2 .navbar-nav li a:hover, .king-horizontal-danger.king-horizontal-nav2 .navbar-nav li a:active {
  background: #d26a5c;
  color: #fff; }
.king-horizontal-danger.king-horizontal-nav2 .navbar-nav li.king-navbar-active a {
  background: #d26a5c;
  color: #fff; }

/* 横向导航菜单样例三*/
.king-horizontal-nav3 {
  border: none;
  border-radius: 0;
  background: #2e3e4e;
  margin-bottom: 0;
  height: 50px; }
  .king-horizontal-nav3 .dropdown-menu {
    padding: 0; }
  .king-horizontal-nav3 .navbar-header .navbar-brand {
    color: #fff;
    margin-right: 50px; }
    .king-horizontal-nav3 .navbar-header .navbar-brand .logo {
      margin-top: -5px; }
  .king-horizontal-nav3 .navbar-header .navbar-toggle {
    margin-top: 3px; }
    .king-horizontal-nav3 .navbar-header .navbar-toggle .icon-bar {
      background: #fff; }
  .king-horizontal-nav3 .navbar-nav > li > a {
    color: #fff;
    height: 50px;
    padding-right: 20px;
    padding-left: 20px; }
    .king-horizontal-nav3 .navbar-nav > li > a:hover, .king-horizontal-nav3 .navbar-nav > li > a:focus {
      color: #fff;
      background: #41586e; }
  .king-horizontal-nav3 .navbar-nav .bk-cur > a {
    color: #fff;
    background: #1b252e !important; }
  .king-horizontal-nav3 .navbar-form {
    padding: 0;
    margin: 4px 0 0 15px;
    border: none; }
  .king-horizontal-nav3 .form-control {
    -webkit-border-radius: 24px !important;
    -moz-border-radius: 24px !important;
    border-radius: 24px !important;
    margin-top: 8px;
    border: none; }
  .king-horizontal-nav3 .avatar {
    width: 30px;
    height: 30px;
    border-radius: 50%;
    margin-top: -5px; }

.king-horizontal-info.king-horizontal-nav3 {
  background: #4A9BFF; }
  .king-horizontal-info.king-horizontal-nav3 .navbar-nav > li > a {
    color: #fff; }
    .king-horizontal-info.king-horizontal-nav3 .navbar-nav > li > a:hover, .king-horizontal-info.king-horizontal-nav3 .navbar-nav > li > a:focus {
      color: #fff;
      background: #7db7ff; }
  .king-horizontal-info.king-horizontal-nav3 .navbar-nav .bk-cur a {
    color: #fff;
    background: #177fff !important; }

.king-horizontal-default.king-horizontal-nav3 {
  background: #f4f4f4; }
  .king-horizontal-default.king-horizontal-nav3 .navbar-nav > li > a {
    color: #555; }
    .king-horizontal-default.king-horizontal-nav3 .navbar-nav > li > a:hover, .king-horizontal-default.king-horizontal-nav3 .navbar-nav > li > a:focus {
      color: #555;
      background: white; }
  .king-horizontal-default.king-horizontal-nav3 .navbar-nav .bk-cur a {
    color: #555;
    background: #dbdbdb !important; }

.king-horizontal-primary.king-horizontal-nav3 {
  background: #5c90d2; }
  .king-horizontal-primary.king-horizontal-nav3 .navbar-nav > li > a {
    color: #fff; }
    .king-horizontal-primary.king-horizontal-nav3 .navbar-nav > li > a:hover, .king-horizontal-primary.king-horizontal-nav3 .navbar-nav > li > a:focus {
      color: #fff;
      background: #84abdd; }
  .king-horizontal-primary.king-horizontal-nav3 .navbar-nav .bk-cur a {
    color: #fff;
    background: #3675c5 !important; }

.king-horizontal-warning.king-horizontal-nav3 {
  background: #f3b760; }
  .king-horizontal-warning.king-horizontal-nav3 .navbar-nav > li > a {
    color: #fff; }
    .king-horizontal-warning.king-horizontal-nav3 .navbar-nav > li > a:hover, .king-horizontal-warning.king-horizontal-nav3 .navbar-nav > li > a:focus {
      color: #fff;
      background: #f7cc8f; }
  .king-horizontal-warning.king-horizontal-nav3 .navbar-nav .bk-cur a {
    color: #fff;
    background: #efa231 !important; }

.king-horizontal-success.king-horizontal-nav3 {
  background: #44B549; }
  .king-horizontal-success.king-horizontal-nav3 .navbar-nav > li > a {
    color: #fff; }
    .king-horizontal-success.king-horizontal-nav3 .navbar-nav > li > a:hover, .king-horizontal-success.king-horizontal-nav3 .navbar-nav > li > a:focus {
      color: #fff;
      background: #66c66b; }
  .king-horizontal-success.king-horizontal-nav3 .navbar-nav .bk-cur a {
    color: #fff;
    background: #36903a !important; }

.king-horizontal-danger.king-horizontal-nav3 {
  background: #d26a5c; }
  .king-horizontal-danger.king-horizontal-nav3 .navbar-nav > li > a {
    color: #fff; }
    .king-horizontal-danger.king-horizontal-nav3 .navbar-nav > li > a:hover, .king-horizontal-danger.king-horizontal-nav3 .navbar-nav > li > a:focus {
      color: #fff;
      background: #dd8f84; }
  .king-horizontal-danger.king-horizontal-nav3 .navbar-nav .bk-cur a {
    color: #fff;
    background: #c54736 !important; }

@media (max-width: 767px) {
  .king-horizontal-nav3 .navbar-nav .open .dropdown-menu li a {
    color: #fff; } }
/* 横向导航菜单样例四*/
.king-horizontal-nav4 {
  width: 100%;
  height: 58px;
  border-width: 0px 0;
  border-style: solid;
  border-color: #ddd;
  border-bottom: 1px solid #ddd;
  background: #fafafa;
  position: relative; }
  .king-horizontal-nav4 .logo_wrap {
    float: left;
    height: 41px;
    margin-top: 7px; }
    .king-horizontal-nav4 .logo_wrap a {
      float: left;
      display: block;
      font-size: 14px; }
      .king-horizontal-nav4 .logo_wrap a.logo_app {
        width: 136px;
        height: 41px;
        text-indent: -9999px;
        background: url(img/example_navs/logo.png) no-repeat; }
      .king-horizontal-nav4 .logo_wrap a.logo_business {
        margin-top: 2px;
        width: 45px;
        height: 40px; }
    .king-horizontal-nav4 .logo_wrap span {
      float: left;
      display: block;
      margin: 6px 16px 0;
      width: 1px;
      height: 34px;
      border-left: 1px solid #ccc; }
  .king-horizontal-nav4 a:hover {
    text-decoration: none; }
  .king-horizontal-nav4 .nav_wrap {
    float: right; }
    .king-horizontal-nav4 .nav_wrap span {
      float: left;
      margin-left: 32px;
      text-align: center;
      line-height: 58px;
      font-size: 14px; }
    .king-horizontal-nav4 .nav_wrap > ul {
      position: relative;
      float: left;
      z-index: 10; }
      .king-horizontal-nav4 .nav_wrap > ul > li {
        float: left;
        position: relative; }
        .king-horizontal-nav4 .nav_wrap > ul > li > a {
          display: block;
          line-height: 58px;
          font-size: 16px;
          color: #667;
          padding: 0 14px; }
          .king-horizontal-nav4 .nav_wrap > ul > li > a > i {
            position: absolute;
            right: 6px;
            top: 28px;
            display: block;
            content: "";
            width: 0;
            height: 0;
            border-left: 6px solid transparent;
            border-right: 6px solid transparent;
            border-top: 6px solid #ccc;
            border-bottom: none; }
    .king-horizontal-nav4 .nav_wrap li.active a {
      color: #70B419;
      border-left: 1px solid transparent;
      border-right: 1px solid transparent;
      padding: 0 22px 0 14px; }
    .king-horizontal-nav4 .nav_wrap li a:hover {
      color: #70B419; }

.king-horizontal-nav4 .nav_wrap li.active:before {
  border-color: #c9c9c9 transparent;
  margin-top: -1px; }

.king-horizontal-nav4 .nav_wrap li ul.submenu {
  position: absolute;
  top: 50px;
  left: 0;
  width: 99%;
  border: 1px solid #d3d3d3;
  border-top: 0;
  background: #fff;
  z-index: 10;
  display: none; }

.king-horizontal-nav4 .nav_wrap li ul.submenu li {
  width: 100%; }

.king-horizontal-nav4 .nav_wrap li ul.submenu li a {
  display: block;
  padding: 0 12px;
  height: 30px;
  line-height: 30px;
  color: #667;
  font-size: 16px; }

.king-horizontal-nav4 .nav_wrap li ul.submenu li a:hover {
  color: #666;
  background: #e5e5e5; }

.king-horizontal-nav4 .nav_wrap li.has_submenu:hover ul.subnavbar {
  display: block; }

.king-horizontal-nav4 .nav_wrap .subnavbar {
  position: absolute;
  top: 58px;
  left: -40px;
  width: 500%;
  padding-top: 6px;
  display: none; }

.king-horizontal-nav4 .tmp li.active a {
  padding: 0 14px;
  border: 0; }

.king-horizontal-nav4 .nav_wrap .subnavbar li {
  position: relative;
  float: left;
  margin-right: 10px;
  background: #e3e3e3; }

.king-horizontal-nav4 .nav_wrap .subnavbar li a {
  display: block;
  padding: 0 14px;
  line-height: 28px;
  color: #666;
  font-size: 12px; }

.king-horizontal-nav4 .nav_wrap .subnavbar li.current, .nav_wrap .subnavbar li:hover {
  background: #70B419; }

.king-horizontal-nav4 .nav_wrap .subnavbar li.current a, .nav_wrap .subnavbar li:hover a {
  color: #fff; }

.king-horizontal-nav4 .nav_wrap .subnavbar li ul.has_sub {
  position: absolute;
  top: 28px;
  left: 0;
  width: 100%;
  z-index: 1000;
  display: none; }

.king-horizontal-nav4 .nav_wrap .subnavbar li ul.has_sub li {
  float: inherit;
  margin: 0; }

.king-horizontal-nav4 .nav_wrap .subnavbar li ul.has_sub li a {
  color: #666; }

.king-horizontal-nav4 .nav_wrap .subnavbar li ul.has_sub li:hover a {
  color: #fff; }

.king-horizontal-nav4 .nav_wrap .subnavbar i {
  position: absolute;
  right: 6px;
  top: 12px;
  display: block;
  content: "";
  width: 0;
  height: 0;
  border-left: 4px solid transparent;
  border-right: 4px solid transparent;
  border-top: 4px solid #666;
  border-bottom: none; }

.king-horizontal-nav4 .nav_wrap .subnavbar li:hover ul.has_sub {
  display: block; }

.king-horizontal-nav4 .nav_wrap li:hover ul.subnavbar {
  display: block; }

/*===================================================*\ *
    king-header2
\*===================================================*/
.king-header2 {
  width: 100%;
  overflow: visible; }
  .king-header2.king-header-fixed {
    position: fixed;
    top: 0;
    z-index: 400; }
  .king-header2 .navbar-header {
    color: #d7e5f8; }
  .king-header2 .navbar-brand {
    position: relative;
    display: block;
    font-size: 16px;
    color: #fff; }
    .king-header2 .navbar-brand .txt {
      padding: 0 10px 0 35px; }
    .king-header2 .navbar-brand .shape {
      position: absolute;
      display: block;
      top: 0;
      left: 0;
      width: 6px;
      height: 6px;
      background-color: #61cc2f; }
    .king-header2 .navbar-brand .shape1 {
      left: 20px;
      top: 18px; }
    .king-header2 .navbar-brand .shape2 {
      left: 30px;
      top: 16px;
      background-color: #ffbe66;
      -webkit-transform: rotate(45deg);
      transform: rotate(45deg); }
    .king-header2 .navbar-brand .shape3 {
      left: 20px;
      top: 26px; }
    .king-header2 .navbar-brand .shape4 {
      left: 28px;
      top: 26px; }
  .king-header2 li .avatar {
    width: 40px;
    height: 40px;
    display: inline-block;
    position: relative;
    margin: -12px 0 -12px 10px; }
    .king-header2 li .avatar img {
      border-radius: 50%;
      width: 40px;
      height: 40px; }
  .king-header2 .navbar-toggle-sm {
    line-height: 14px;
    margin-right: 0; }
  .king-header2.navbar-blue {
    background-color: #147bd0;
    border-radius: 0;
    border: 0; }
    .king-header2.navbar-blue .nav > li > a {
      color: #d7e5f8;
      -webkit-transition: all 0.13s linear;
      transition: all 0.13s linear; }
      .king-header2.navbar-blue .nav > li > a:hover, .king-header2.navbar-blue .nav > li > a:focus, .king-header2.navbar-blue .nav > li > a.active {
        color: #fff;
        background-color: #0669BB; }
    .king-header2.navbar-blue .nav > li:hover, .king-header2.navbar-blue .nav > li:focus {
      color: #fff;
      background-color: #0669BB; }
    .king-header2.navbar-blue .nav .open > a {
      color: #fff;
      background-color: #0669BB; }
      .king-header2.navbar-blue .nav .open > a:hover, .king-header2.navbar-blue .nav .open > a:focus {
        color: #fff;
        background-color: #0669BB; }
  .king-header2 .navbar-nav .open .dropdown-menu {
    background-color: #fff; }
  .king-header2 .caret-down {
    display: inline-block;
    width: 0;
    height: 0;
    border: 3px solid #bdd0eb;
    border-left-color: transparent;
    border-top-color: transparent;
    margin: 6px 0 0 10px; }

.king-business-select {
  margin: 15px; }

.king-business-title {
  font-weight: bold; }

.king-horizontal-info.king-header2 {
  background-color: #4A9BFF;
  border-radius: 0;
  border: 0; }
  .king-horizontal-info.king-header2 .nav > li > a {
    color: #fff;
    -webkit-transition: all 0.13s linear;
    transition: all 0.13s linear; }
    .king-horizontal-info.king-header2 .nav > li > a:hover, .king-horizontal-info.king-header2 .nav > li > a:focus, .king-horizontal-info.king-header2 .nav > li > a.active {
      color: #fff;
      background-color: #177fff; }
  .king-horizontal-info.king-header2 .nav > li:hover, .king-horizontal-info.king-header2 .nav > li:focus {
    color: #fff;
    background-color: #177fff; }
  .king-horizontal-info.king-header2 .nav .open > a {
    color: #fff;
    background-color: #177fff; }
    .king-horizontal-info.king-header2 .nav .open > a:hover, .king-horizontal-info.king-header2 .nav .open > a:focus {
      color: #fff;
      background-color: #177fff; }

.king-horizontal-default.king-header2 {
  background-color: #f4f4f4;
  border-radius: 0;
  border: 0; }
  .king-horizontal-default.king-header2 .nav > li > a {
    color: #555;
    -webkit-transition: all 0.13s linear;
    transition: all 0.13s linear; }
    .king-horizontal-default.king-header2 .nav > li > a:hover, .king-horizontal-default.king-header2 .nav > li > a:focus, .king-horizontal-default.king-header2 .nav > li > a.active {
      color: #555;
      background-color: #dbdbdb; }
  .king-horizontal-default.king-header2 .nav > li:hover, .king-horizontal-default.king-header2 .nav > li:focus {
    color: #555;
    background-color: #dbdbdb; }
  .king-horizontal-default.king-header2 .nav .open > a {
    color: #555;
    background-color: #dbdbdb; }
    .king-horizontal-default.king-header2 .nav .open > a:hover, .king-horizontal-default.king-header2 .nav .open > a:focus {
      color: #555;
      background-color: #dbdbdb; }

.king-horizontal-primary.king-header2 {
  background-color: #5c90d2;
  border-radius: 0;
  border: 0; }
  .king-horizontal-primary.king-header2 .nav > li > a {
    color: #fff;
    -webkit-transition: all 0.13s linear;
    transition: all 0.13s linear; }
    .king-horizontal-primary.king-header2 .nav > li > a:hover, .king-horizontal-primary.king-header2 .nav > li > a:focus, .king-horizontal-primary.king-header2 .nav > li > a.active {
      color: #fff;
      background-color: #3675c5; }
  .king-horizontal-primary.king-header2 .nav > li:hover, .king-horizontal-primary.king-header2 .nav > li:focus {
    color: #fff;
    background-color: #3675c5; }
  .king-horizontal-primary.king-header2 .nav .open > a {
    color: #fff;
    background-color: #3675c5; }
    .king-horizontal-primary.king-header2 .nav .open > a:hover, .king-horizontal-primary.king-header2 .nav .open > a:focus {
      color: #fff;
      background-color: #3675c5; }

.king-horizontal-warning.king-header2 {
  background-color: #f3b760;
  border-radius: 0;
  border: 0; }
  .king-horizontal-warning.king-header2 .nav > li > a {
    color: #fff;
    -webkit-transition: all 0.13s linear;
    transition: all 0.13s linear; }
    .king-horizontal-warning.king-header2 .nav > li > a:hover, .king-horizontal-warning.king-header2 .nav > li > a:focus, .king-horizontal-warning.king-header2 .nav > li > a.active {
      color: #fff;
      background-color: #efa231; }
  .king-horizontal-warning.king-header2 .nav > li:hover, .king-horizontal-warning.king-header2 .nav > li:focus {
    color: #fff;
    background-color: #efa231; }
  .king-horizontal-warning.king-header2 .nav .open > a {
    color: #fff;
    background-color: #efa231; }
    .king-horizontal-warning.king-header2 .nav .open > a:hover, .king-horizontal-warning.king-header2 .nav .open > a:focus {
      color: #fff;
      background-color: #efa231; }

.king-horizontal-success.king-header2 {
  background-color: #44B549;
  border-radius: 0;
  border: 0; }
  .king-horizontal-success.king-header2 .nav > li > a {
    color: #fff;
    -webkit-transition: all 0.13s linear;
    transition: all 0.13s linear; }
    .king-horizontal-success.king-header2 .nav > li > a:hover, .king-horizontal-success.king-header2 .nav > li > a:focus, .king-horizontal-success.king-header2 .nav > li > a.active {
      color: #fff;
      background-color: #34a263; }
  .king-horizontal-success.king-header2 .nav > li:hover, .king-horizontal-success.king-header2 .nav > li:focus {
    color: #fff;
    background-color: #34a263; }
  .king-horizontal-success.king-header2 .nav .open > a {
    color: #fff;
    background-color: #34a263; }
    .king-horizontal-success.king-header2 .nav .open > a:hover, .king-horizontal-success.king-header2 .nav .open > a:focus {
      color: #fff;
      background-color: #34a263; }

.king-horizontal-danger.king-header2 {
  background-color: #d26a5c;
  border-radius: 0;
  border: 0; }
  .king-horizontal-danger.king-header2 .nav > li > a {
    color: #fff;
    -webkit-transition: all 0.13s linear;
    transition: all 0.13s linear; }
    .king-horizontal-danger.king-header2 .nav > li > a:hover, .king-horizontal-danger.king-header2 .nav > li > a:focus, .king-horizontal-danger.king-header2 .nav > li > a.active {
      color: #fff;
      background-color: #c54736; }
  .king-horizontal-danger.king-header2 .nav > li:hover, .king-horizontal-danger.king-header2 .nav > li:focus {
    color: #fff;
    background-color: #c54736; }
  .king-horizontal-danger.king-header2 .nav .open > a {
    color: #fff;
    background-color: #c54736; }
    .king-horizontal-danger.king-header2 .nav .open > a:hover, .king-horizontal-danger.king-header2 .nav .open > a:focus {
      color: #fff;
      background-color: #c54736; }

/* 纵向导航菜单样例十*/
.king-vertical-nav10 {
  width: 80px;
  background: #2a2b3c; }
  .king-vertical-nav10.king-full-height {
    height: 100%; }
  .king-vertical-nav10 .sidebar-inner {
    padding: 80px 0px 120px 0px; }
  .king-vertical-nav10 ul {
    text-align: left;
    padding: 0;
    margin: 0;
    list-style-type: none; }
  .king-vertical-nav10 .navi li a {
    display: block;
    width: 100%;
    height: 65px;
    padding-top: 13px;
    text-align: center;
    color: #fff;
    font-size: 12px;
    text-decoration: none; }
  .king-vertical-nav10 .navi > li {
    position: relative;
    border-bottom: #252636 1px solid; }
    .king-vertical-nav10 .navi > li:hover {
      background-color: #252636;
      border-bottom: #252636 1px solid; }
      .king-vertical-nav10 .navi > li:hover .sub-menu {
        display: block;
        z-index: 10; }
    .king-vertical-nav10 .navi > li.active, .king-vertical-nav10 .navi > li.active:hover {
      background-color: #a54e4c; }
    .king-vertical-nav10 .navi > li .fa {
      display: block;
      font-size: 20px;
      color: #fff; }
  .king-vertical-nav10 .navi .sub-menu {
    display: none;
    position: absolute;
    left: 80px;
    top: 0px;
    min-width: 200px;
    padding: 10px;
    background-color: #252636; }
    .king-vertical-nav10 .navi .sub-menu li {
      border: none;
      padding: 0;
      line-height: 40px; }
      .king-vertical-nav10 .navi .sub-menu li.active a {
        background-color: #a54e4c;
        color: #fff; }
      .king-vertical-nav10 .navi .sub-menu li a {
        position: relative;
        display: block;
        height: auto;
        line-height: 1em;
        padding: 8px 20px;
        color: #fff;
        white-space: nowrap;
        text-align: left; }
        .king-vertical-nav10 .navi .sub-menu li a:hover {
          background-color: #a54e4c;
          color: #fff; }
  .king-vertical-nav10 .navi .has-submenu > a {
    cursor: default; }

.king-vertical-nav10-info.king-vertical-nav10 {
  background-color: #177fff; }
  .king-vertical-nav10-info.king-vertical-nav10 .navi > li {
    border-bottom: #0071fd 1px solid; }
    .king-vertical-nav10-info.king-vertical-nav10 .navi > li:hover {
      background-color: #4A9BFF;
      border-bottom: #4A9BFF 1px solid; }
    .king-vertical-nav10-info.king-vertical-nav10 .navi > li.active, .king-vertical-nav10-info.king-vertical-nav10 .navi > li.active:hover {
      background-color: #4A9BFF; }
  .king-vertical-nav10-info.king-vertical-nav10 .navi .sub-menu {
    background-color: #4A9BFF; }
    .king-vertical-nav10-info.king-vertical-nav10 .navi .sub-menu li.active a {
      background-color: #177fff; }
    .king-vertical-nav10-info.king-vertical-nav10 .navi .sub-menu li a:hover {
      background-color: #177fff; }

.king-vertical-nav10-primary.king-vertical-nav10 {
  background-color: #3675c5; }
  .king-vertical-nav10-primary.king-vertical-nav10 .navi > li {
    border-bottom: #3169b1 1px solid; }
    .king-vertical-nav10-primary.king-vertical-nav10 .navi > li:hover {
      background-color: #5c90d2;
      border-bottom: #5c90d2 1px solid; }
    .king-vertical-nav10-primary.king-vertical-nav10 .navi > li.active, .king-vertical-nav10-primary.king-vertical-nav10 .navi > li.active:hover {
      background-color: #5c90d2; }
  .king-vertical-nav10-primary.king-vertical-nav10 .navi .sub-menu {
    background-color: #5c90d2; }
    .king-vertical-nav10-primary.king-vertical-nav10 .navi .sub-menu li.active a {
      background-color: #3675c5; }
    .king-vertical-nav10-primary.king-vertical-nav10 .navi .sub-menu li a:hover {
      background-color: #3675c5; }

.king-vertical-nav10-warning.king-vertical-nav10 {
  background-color: #efa231; }
  .king-vertical-nav10-warning.king-vertical-nav10 .navi > li {
    border-bottom: #ee9719 1px solid; }
    .king-vertical-nav10-warning.king-vertical-nav10 .navi > li:hover {
      background-color: #f3b760;
      border-bottom: #f3b760 1px solid; }
    .king-vertical-nav10-warning.king-vertical-nav10 .navi > li.active, .king-vertical-nav10-warning.king-vertical-nav10 .navi > li.active:hover {
      background-color: #f3b760; }
  .king-vertical-nav10-warning.king-vertical-nav10 .navi .sub-menu {
    background-color: #f3b760; }
    .king-vertical-nav10-warning.king-vertical-nav10 .navi .sub-menu li.active a {
      background-color: #efa231; }
    .king-vertical-nav10-warning.king-vertical-nav10 .navi .sub-menu li a:hover {
      background-color: #efa231; }

.king-vertical-nav10-danger.king-vertical-nav10 {
  background-color: #c54736; }
  .king-vertical-nav10-danger.king-vertical-nav10 .navi > li {
    border-bottom: #b14031 1px solid; }
    .king-vertical-nav10-danger.king-vertical-nav10 .navi > li:hover {
      background-color: #d26a5c;
      border-bottom: #d26a5c 1px solid; }
    .king-vertical-nav10-danger.king-vertical-nav10 .navi > li.active, .king-vertical-nav10-danger.king-vertical-nav10 .navi > li.active:hover {
      background-color: #d26a5c; }
  .king-vertical-nav10-danger.king-vertical-nav10 .navi .sub-menu {
    background-color: #d26a5c; }
    .king-vertical-nav10-danger.king-vertical-nav10 .navi .sub-menu li.active a {
      background-color: #c54736; }
    .king-vertical-nav10-danger.king-vertical-nav10 .navi .sub-menu li a:hover {
      background-color: #c54736; }

.king-vertical-nav10-success.king-vertical-nav10 {
  background-color: #36903a; }
  .king-vertical-nav10-success.king-vertical-nav10 .navi > li {
    border-bottom: #2f7d33 1px solid; }
    .king-vertical-nav10-success.king-vertical-nav10 .navi > li:hover {
      background-color: #44B549;
      border-bottom: #44B549 1px solid; }
    .king-vertical-nav10-success.king-vertical-nav10 .navi > li.active, .king-vertical-nav10-success.king-vertical-nav10 .navi > li.active:hover {
      background-color: #44B549; }
  .king-vertical-nav10-success.king-vertical-nav10 .navi .sub-menu {
    background-color: #44B549; }
    .king-vertical-nav10-success.king-vertical-nav10 .navi .sub-menu li.active a {
      background-color: #36903a; }
    .king-vertical-nav10-success.king-vertical-nav10 .navi .sub-menu li a:hover {
      background-color: #36903a; }

/*===================================================*\
 * 由other/index.scss迁移过来，2016.1.27.
\*===================================================*/
/*===================================================*\
 * 自定义横向导航栏样式
\*===================================================*/
.king-header {
  border-bottom: 1px solid #eee;
  position: relative;
  width: 100%;
  min-width: 900px;
  height: 50px;
  background: white; }
  .king-header a {
    text-decoration: none; }

.king-header-inner {
  height: 50px;
  margin: 0 auto;
  min-width: 900px;
  max-width: 1200px; }

.king-header-brand {
  float: left;
  height: 50px; }
  .king-header-brand img {
    margin-top: 10px;
    margin-left: 5px; }

.king-header-list {
  float: right;
  height: 50px; }
  .king-header-list > ul {
    margin: 0px;
    padding: 0;
    font-size: 0;
    -webkit-text-size-adjust: none; }
    .king-header-list > ul > li {
      display: inline-block;
      height: 100%;
      line-height: 50px;
      font-size: 12px;
      position: relative; }
      .king-header-list > ul > li > a {
        color: #696969;
        font-size: 14px;
        position: relative;
        display: block; }
        .king-header-list > ul > li > a span {
          border-left: 1px solid #f2f2f2;
          padding: 0px 15px; }
  .king-header-list.list2 a {
    padding-left: 15px;
    padding-right: 15px; }
  .king-header-list.list2 > ul > li a > {
    border-left: none; }
  .king-header-list.list1 {
    padding-left: 20px; }
  .king-header-list .list-home {
    border-left: none; }

/*===================================================*\
 * 自定义横向导航栏样式 horizontal_nav5
\*===================================================*/
.king-header1 .king-header-list > ul > li a:after {
  content: "";
  height: 2px;
  width: 100%;
  position: absolute;
  left: 0;
  top: 0;
  z-index: 203;
  background: #909090;
  display: none; }
.king-header1 .list1 > ul > li:hover > a:after {
  display: block; }
.king-header1 .list1 > ul > li .active > a:after {
  display: block; }

/* king-header1 blue */
.king-header1.king-header-blue .king-header-list.list1 > ul > li:hover > a, .king-header1.king-header-blue .king-header-list.list1 > ul > li.active > a {
  color: #4A9BFF; }

.king-header1.king-header-blue .king-header-list > ul > li > a:after {
  background: #4A9BFF; }

/* king-header1 blue2 */
.king-header1.king-header-blue2 .king-header-list.list1 > ul > li:hover > a, .king-header1.king-header-blue2 .king-header-list.list1 > ul > li.active > a {
  color: #5C90D2; }

.king-header1.king-header-blue2 .king-header-list > ul > li > a:after {
  background: #5C90D2; }

/* king-header1 red */
.king-header1.king-header-red .king-header-list.list1 > ul > li:hover > a, .king-header1.king-header-red .king-header-list.list1 > ul > li.active > a {
  color: #D26A5C; }

.king-header1.king-header-red .king-header-list > ul > li > a:after {
  background: #D26A5C; }

/* king-header1 green */
.king-header1.king-header-green .king-header-list.list1 > ul > li:hover > a, .king-header1.king-header-green .king-header-list.list1 > ul > li.active > a {
  color: #46C37B; }

.king-header1.king-header-green .king-header-list > ul > li > a:after {
  background: #46C37B; }

/* king-header1 gold */
.king-header1.king-header-gold .king-header-list.list1 > ul > li:hover > a, .king-header1.king-header-gold .king-header-list.list1 > ul > li.active > a {
  color: #F3B760; }

.king-header1.king-header-gold .king-header-list > ul > li > a:after {
  background: #F3B760; }

/*===================================================*\
 * 自定义横向导航栏样式 horizontal_nav6
\*===================================================*/
.king-header2 {
  margin-bottom: 0;
  box-shadow: 1px 1px 2px #eee; }
  .king-header2 .king-header-list.list1 {
    float: left; }
  .king-header2 .king-header-list > ul > li > a:after {
    content: "";
    height: 4px;
    width: 100%;
    position: absolute;
    left: 0;
    bottom: -4px;
    z-index: 203;
    background: #909090;
    display: none; }
  .king-header2 .king-header-list > ul > li > a span {
    border-left: none; }
  .king-header2 .list1 > ul > li:hover > a:after {
    display: block; }
  .king-header2 .list1 > ul > li.active > a:after {
    display: block; }
  .king-header2.king-header-blue .king-header-list.list1 > ul > li:hover > a {
    color: #4A9BFF; }
  .king-header2.king-header-blue .king-header-list.list1 > ul > li.active > a {
    color: #4A9BFF; }
  .king-header2.king-header-blue .king-header-list.list1 > ul > li > a:after {
    background: #4A9BFF; }
  .king-header2.king-header-blue2 .king-header-list.list1 > ul > li:hover > a {
    color: #5C90D2; }
  .king-header2.king-header-blue2 .king-header-list.list1 > ul > li.active > a {
    color: #5C90D2; }
  .king-header2.king-header-blue2 .king-header-list.list1 > ul > li > a:after {
    background: #5C90D2; }
  .king-header2.king-header-red .king-header-list.list1 > ul > li:hover > a {
    color: #D26A5C; }
  .king-header2.king-header-red .king-header-list.list1 > ul > li.active > a {
    color: #D26A5C; }
  .king-header2.king-header-red .king-header-list.list1 > ul > li > a:after {
    background: #D26A5C; }
  .king-header2.king-header-green .king-header-list.list1 > ul > li:hover > a {
    color: #46C37B; }
  .king-header2.king-header-green .king-header-list.list1 > ul > li.active > a {
    color: #46C37B; }
  .king-header2.king-header-green .king-header-list.list1 > ul > li > a:after {
    background: #46C37B; }
  .king-header2.king-header-gold .king-header-list.list1 > ul > li:hover > a {
    color: #F3B760; }
  .king-header2.king-header-gold .king-header-list.list1 > ul > li.active > a {
    color: #F3B760; }
  .king-header2.king-header-gold .king-header-list.list1 > ul > li > a:after {
    background: #F3B760; }

/*===================================================*\
 * 自定义横向导航栏样式 horizontal_nav8
\*===================================================*/
.king-submenu {
  margin: 0;
  padding: 0px;
  min-width: 100%;
  width: auto;
  display: block;
  white-space: nowrap;
  position: absolute;
  top: 48px;
  left: 0;
  border-top: 2px solid #6ec2cc;
  z-index: 1003;
  background: white;
  display: none;
  border-left: 1px solid #eee;
  border-right: 1px solid #eee; }
  .king-submenu li {
    border-bottom: 1px solid #eee; }
    .king-submenu li:hover {
      background: #f7f7f7; }
      .king-submenu li:hover a {
        color: #6ec2cc; }
    .king-submenu li a {
      color: #696969;
      padding: 0 10px;
      display: block; }

.king-header4 .list1 > ul > li:hover .king-submenu {
  display: block; }
.king-header4.king-header-blue .king-header-list.list1 > ul > li:hover > a {
  color: #4A9BFF; }
.king-header4.king-header-blue .king-header-list.list1 > ul > li.active > a {
  color: #4A9BFF; }
.king-header4.king-header-blue .king-submenu {
  border-top: 2px solid #4A9BFF; }
  .king-header4.king-header-blue .king-submenu li:hover a {
    color: #4A9BFF; }
.king-header4.king-header-blue2 .king-header-list.list1 > ul > li:hover > a {
  color: #5C90D2; }
.king-header4.king-header-blue2 .king-header-list.list1 > ul > li.active > a {
  color: #5C90D2; }
.king-header4.king-header-blue2 .king-submenu {
  border-top: 2px solid #5C90D2; }
  .king-header4.king-header-blue2 .king-submenu li:hover a {
    color: #5C90D2; }
.king-header4.king-header-red .king-header-list.list1 > ul > li:hover > a {
  color: #D26A5C; }
.king-header4.king-header-red .king-header-list.list1 > ul > li.active > a {
  color: #D26A5C; }
.king-header4.king-header-red .king-submenu {
  border-top: 2px solid #D26A5C; }
  .king-header4.king-header-red .king-submenu li:hover a {
    color: #D26A5C; }
.king-header4.king-header-green .king-header-list.list1 > ul > li:hover > a {
  color: #46C37B; }
.king-header4.king-header-green .king-header-list.list1 > ul > li.active > a {
  color: #46C37B; }
.king-header4.king-header-green .king-submenu {
  border-top: 2px solid #46C37B; }
  .king-header4.king-header-green .king-submenu li:hover a {
    color: #46C37B; }
.king-header4.king-header-gold .king-header-list.list1 > ul > li:hover > a {
  color: #F3B760; }
.king-header4.king-header-gold .king-header-list.list1 > ul > li.active > a {
  color: #F3B760; }
.king-header4.king-header-gold .king-submenu {
  border-top: 2px solid #F3B760; }
  .king-header4.king-header-gold .king-submenu li:hover a {
    color: #F3B760; }

/*===================================================*\
 * topbar Breadcrumb template5
\*===================================================*/
.king-topbar {
  padding: 15px 0;
  background-color: #f6f8f8;
  border-bottom: 1px solid #e3e5e7;
  overflow: hidden; }
  .king-topbar h1 {
    font-size: 16px;
    font-weight: bold;
    margin: 0; }
  .king-topbar .title {
    display: inline-block;
    padding: 15px 0;
    line-height: 20px;
    margin-right: 20px;
    font-size: 16px;
    font-weight: 600; }
  .king-topbar .king-topbar-nav {
    display: inline-block;
    vertical-align: top; }
    .king-topbar .king-topbar-nav li {
      display: inline-block;
      margin-right: 18px; }
      .king-topbar .king-topbar-nav li:last-child {
        margin-right: 0; }
      .king-topbar .king-topbar-nav li a {
        display: block;
        padding: 15px 5px;
        color: #666;
        -webkit-transition: all 0.13s linear;
        transition: all 0.13s linear; }
        .king-topbar .king-topbar-nav li a:hover {
          color: #23b7e5;
          text-decoration: none; }
        .king-topbar .king-topbar-nav li a:focus {
          color: #23b7e5;
          text-decoration: none; }
      .king-topbar .king-topbar-nav li.active a {
        color: #23b7e5;
        -webkit-box-shadow: inset 0 -1px 0 #23b7e5;
        box-shadow: inset 0 -1px 0 #23b7e5; }
  .king-topbar .row {
    width: 1200px;
    margin: auto; }
  .king-topbar .breadcrumb {
    margin: 0;
    padding: 0; }

.king-body {
  width: 1200px;
  margin: auto; }

.king-no-bg {
  background: none !important; }

.king-no-tm {
  margin-top: 0 !important; }

.king-no-m {
  margin: 0 !important; }

.inline-block {
  display: inline-block !important;
  vertical-align: middle; }

.king-select {
  width: auto; }

.magic-topbar-container {
  z-index: 999;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  font-family: microsoft yahei,Arial,sans-serif;
  font-size: 16px;
  position: fixed;
  top: 0;
  width: 100%;
  height: auto;
  padding: 15px 30px;
  text-align: center; }

/*===================================================*\
 * 自定义横向导航栏样式 horizontal_nav10
\*===================================================*/
.king-horizontal-nav10 {
  background-color: #262626;
  height: 54px;
  width: 100%;
  min-width: 800px; }
  .king-horizontal-nav10 .navbar-brand {
    width: 220px;
    height: 54px;
    padding: 12px 0 0 15px; }
  .king-horizontal-nav10 .navbar-nav {
    float: left;
    margin: 0; }
    .king-horizontal-nav10 .navbar-nav li {
      float: left; }
  .king-horizontal-nav10 .navbar-header {
    float: left; }
  .king-horizontal-nav10 .img-rounded {
    width: 42px;
    height: 42px;
    border-radius: 50%;
    margin-left: 11px; }
  .king-horizontal-nav10 li a {
    height: 54px;
    line-height: 54px;
    padding: 0 15px;
    color: #999; }
  .king-horizontal-nav10 .nav {
    position: relative; }
    .king-horizontal-nav10 .nav .navslip {
      background-color: #85c030;
      position: absolute;
      height: 3px;
      width: 0px;
      left: 0; }
    .king-horizontal-nav10 .nav > li > a:not(:last-child) {
      border-top: 3px solid transparent; }
    .king-horizontal-nav10 .nav > li > a:hover {
      background: #262626; }
    .king-horizontal-nav10 .nav > li > a:focus, .king-horizontal-nav10 .nav > li.active a {
      background: #262626;
      color: #d0d0d0; }

.king-horizontal-info.king-horizontal-nav10 {
  background-color: #4A9BFF; }
  .king-horizontal-info.king-horizontal-nav10 .nav {
    position: relative; }
    .king-horizontal-info.king-horizontal-nav10 .nav .navslip {
      background-color: #85c030; }
    .king-horizontal-info.king-horizontal-nav10 .nav > li > a:hover {
      background: #177fff; }
    .king-horizontal-info.king-horizontal-nav10 .nav > li > a:focus, .king-horizontal-info.king-horizontal-nav10 .nav > li.active a {
      background: #177fff;
      color: #fff; }
  .king-horizontal-info.king-horizontal-nav10 li a {
    color: #fff; }

.king-horizontal-default.king-horizontal-nav10 {
  background-color: #f4f4f4; }
  .king-horizontal-default.king-horizontal-nav10 .nav {
    position: relative; }
    .king-horizontal-default.king-horizontal-nav10 .nav .navslip {
      background-color: #85c030; }
    .king-horizontal-default.king-horizontal-nav10 .nav > li > a:hover {
      background: #dbdbdb; }
    .king-horizontal-default.king-horizontal-nav10 .nav > li > a:focus, .king-horizontal-default.king-horizontal-nav10 .nav > li.active a {
      background: #dbdbdb;
      color: #555; }
  .king-horizontal-default.king-horizontal-nav10 li a {
    color: #555; }

.king-horizontal-primary.king-horizontal-nav10 {
  background-color: #5c90d2; }
  .king-horizontal-primary.king-horizontal-nav10 .nav {
    position: relative; }
    .king-horizontal-primary.king-horizontal-nav10 .nav .navslip {
      background-color: #85c030; }
    .king-horizontal-primary.king-horizontal-nav10 .nav > li > a:hover {
      background: #3675c5; }
    .king-horizontal-primary.king-horizontal-nav10 .nav > li > a:focus, .king-horizontal-primary.king-horizontal-nav10 .nav > li.active a {
      background: #3675c5;
      color: #fff; }
  .king-horizontal-primary.king-horizontal-nav10 li a {
    color: #fff; }

.king-horizontal-warning.king-horizontal-nav10 {
  background-color: #f3b760; }
  .king-horizontal-warning.king-horizontal-nav10 .nav {
    position: relative; }
    .king-horizontal-warning.king-horizontal-nav10 .nav .navslip {
      background-color: #85c030; }
    .king-horizontal-warning.king-horizontal-nav10 .nav > li > a:hover {
      background: #efa231; }
    .king-horizontal-warning.king-horizontal-nav10 .nav > li > a:focus, .king-horizontal-warning.king-horizontal-nav10 .nav > li.active a {
      background: #efa231;
      color: #fff; }
  .king-horizontal-warning.king-horizontal-nav10 li a {
    color: #fff; }

.king-horizontal-success.king-horizontal-nav10 {
  background-color: #44B549; }
  .king-horizontal-success.king-horizontal-nav10 .nav {
    position: relative; }
    .king-horizontal-success.king-horizontal-nav10 .nav .navslip {
      background-color: #85c030; }
    .king-horizontal-success.king-horizontal-nav10 .nav > li > a:hover {
      background: #34a263; }
    .king-horizontal-success.king-horizontal-nav10 .nav > li > a:focus, .king-horizontal-success.king-horizontal-nav10 .nav > li.active a {
      background: #34a263;
      color: #fff; }
  .king-horizontal-success.king-horizontal-nav10 li a {
    color: #fff; }

.king-horizontal-danger.king-horizontal-nav10 {
  background-color: #d26a5c; }
  .king-horizontal-danger.king-horizontal-nav10 .nav {
    position: relative; }
    .king-horizontal-danger.king-horizontal-nav10 .nav .navslip {
      background-color: #85c030; }
    .king-horizontal-danger.king-horizontal-nav10 .nav > li > a:hover {
      background: #c54736; }
    .king-horizontal-danger.king-horizontal-nav10 .nav > li > a:focus, .king-horizontal-danger.king-horizontal-nav10 .nav > li.active a {
      background: #c54736;
      color: #fff; }
  .king-horizontal-danger.king-horizontal-nav10 li a {
    color: #fff; }

/*===================================================*\ 
 * * * king-content-header 正文头部
\*===================================================*/
.king-content-header {
  position: relative;
  padding: 15px 15px 0 15px; }

.king-content-header.king-info-header h1 {
  padding-left: 15px;
  border-left: 3px solid #4A9BFF; }

.king-content-header.king-info-header {
  overflow: hidden;
  background: #fff;
  padding: 0 0 20px 0;
  border-bottom: 1px solid #ddd; }

.king-content-header.king-info-header > .breadcrumb {
  top: 0; }

.king-content-header > h1 {
  margin: 0;
  font-size: 20px; }

.king-content-header > h1 > small {
  font-size: 15px;
  display: inline-block;
  padding-left: 4px;
  font-weight: 300; }

.king-content-header > .breadcrumb {
  float: right;
  background: transparent;
  margin-top: 0px;
  margin-bottom: 0;
  font-size: 12px;
  padding: 7px 5px;
  position: absolute;
  top: 15px;
  right: 10px;
  border-radius: 2px; }

.king-content-header > .breadcrumb > li > a {
  color: #444;
  text-decoration: none;
  display: inline-block; }

.king-content-header > .breadcrumb > li > a > .fa, .king-content-header > .breadcrumb > li > a > .glyphicon, .king-content-header > .breadcrumb > li > a > .ion {
  margin-right: 5px; }

.king-content-header > .breadcrumb > li + li:before {
  content: '>\00a0'; }

.king-content {
  min-height: 250px;
  padding: 15px;
  margin-right: auto;
  margin-left: auto;
  padding-left: 15px;
  padding-right: 15px; }

.king-layout1-header {
  margin: auto; }

.king-layout1-footer {
  margin: auto; }

.king-layout1-header .king-wrapper {
  margin: auto; }

.king-layout1-main {
  margin: auto;
  height: 100%; }

.king-layout1-sidebar {
  float: left;
  /*min-height: 300px;*/
  /*height: 100%;*/
  margin-right: -100%; }

.king-content-wrap {
  float: left;
  width: 100%; }

.king-layout1-content {
  margin-left: 216px; }

.king-layout2-header {
  min-height: 50px;
  margin: auto;
  min-width: 960px; }

.king-layout2-header .king-wrapper {
  margin: auto; }

.king-layout2-main {
  width: 960px;
  margin: auto; }

.king-layout2-inner {
  margin-right: 210px;
  min-height: 300px; }

.king-layout2-sidebar {
  position: relative;
  float: right;
  width: 200px;
  margin-left: -200px;
  min-height: 300px; }

.king-layout2-content {
  float: left;
  width: 100%; }

.king-layout5-main {
  overflow: hidden; }

.king-layout5-header {
  min-height: 50px;
  margin: auto;
  margin-bottom: 10px; }

.king-layout5-footer {
  min-height: 50px;
  margin: auto;
  margin-top: 10px; }

.king-layout5-left, .king-layout5-right {
  position: relative;
  float: left;
  width: 230px;
  margin: 0 -230px 0 0; }

.king-layout5-right {
  float: right;
  width: 190px;
  margin: 0 0 0 -190px; }

.king-layout5-content {
  float: left;
  width: 100%; }

.king-layout5-inner {
  margin: 0 200px 0 240px; }

.king-layout6-sidebar {
  position: fixed;
  top: 0;
  left: 0;
  min-height: 100%;
  width: 230px;
  z-index: 810;
  bottom: 0; }

.king-layout6-content {
  -webkit-transition: -webkit-transform 0.3s ease-in-out, margin 0.3s ease-in-out;
  -moz-transition: -moz-transform 0.3s ease-in-out, margin 0.3s ease-in-out;
  -o-transition: -o-transform 0.3s ease-in-out, margin 0.3s ease-in-out;
  transition: transform 0.3s ease-in-out, margin 0.3s ease-in-out;
  margin-left: 230px;
  z-index: 820; }

.king-layout6-content {
  min-height: 100%;
  z-index: 800;
  overflow: hidden; }

.king-content-wrapper {
  margin: 20px auto; }

.king-equal-height {
  width: 100%;
  margin: 0 auto;
  overflow: hidden;
  display: inline-block;
  background: #ddd; }

.king-equal-height:after {
  content: "";
  display: block;
  clear: both; }

.king-eh-left {
  width: 20%;
  float: left;
  padding-bottom: 20000px;
  margin-bottom: -20000px;
  background: #eee; }

.king-eh-right {
  width: 20%;
  float: right;
  padding-bottom: 20000px;
  margin-bottom: -20000px;
  background: #eee; }

.king-eh-content {
  float: left;
  width: 60%; }

.king-container {
  margin: auto; }

.king-page-box {
  height: 100%; }

/*===================================================*\
 * 面板样式
\*===================================================*/
.king-panel1 {
  border: 1px solid #ddd;
  border-top: none !important; }

.king-panel-head1 {
  border-bottom: 1px solid #e5e5e5;
  content: '';
  display: block; }

.king-panel-control {
  float: right;
  height: 100%;
  position: relative; }

.king-panel-top1 {
  border-top: 3px solid #999999; }

.king-panel-top2 {
  border-top: 3px solid #4A9BFF; }

.king-panel-top3 {
  border-top: 3px solid #5C90D2; }

.king-panel-top4 {
  border-top: 3px solid #46C37B; }

.king-panel-top5 {
  border-top: 3px solid #F3B760; }

.king-panel-top6 {
  border-top: 3px solid #D26A5C; }

.king-no-margin {
  margin: 0 !important; }

/*===================================================*\
 * 数据展示小部件三
\*===================================================*/
.panel-dark {
  border-color: #242633; }
  .panel-dark > .panel-heading {
    color: #fff;
    background-color: #242633;
    border-color: #242633; }
    .panel-dark > .panel-heading + .panel-collapse > .panel-body {
      border-top-color: #242633; }
    .panel-dark > .panel-heading .badge {
      color: #242633;
      background-color: #fff; }
  .panel-dark > .panel-footer + .panel-collapse > .panel-body {
    border-bottom-color: #242633; }

.panel .panel-heading {
  text-transform: uppercase; }
.panel .panel-title {
  font-size: 14px; }
.panel.panel-box {
  display: table;
  table-layout: fixed;
  width: 100%;
  height: 100%;
  text-align: center;
  border: none; }
  .panel.panel-box .panel-item {
    display: table-cell;
    padding: 30px;
    width: 1%;
    vertical-align: top;
    border-radius: 0; }
  .panel.panel-box .panel-left {
    border-top-left-radius: 4px;
    border-bottom-left-radius: 4px; }
  .panel.panel-box .panel-right {
    border-top-right-radius: 4px;
    border-bottom-right-radius: 4px; }
  .panel.panel-box .panel-bottom, .panel.panel-box .panel-box .panel-top {
    display: block; }
  .panel.panel-box .panel-top {
    padding: 30px 20px;
    border-top-left-radius: 4px;
    border-top-right-radius: 4px; }
  .panel.panel-box .panel-bottom {
    padding: 10px;
    border-bottom-left-radius: 4px;
    border-bottom-right-radius: 4px; }
    .panel.panel-box .panel-bottom p {
      margin: 0; }
  .panel.panel-box .list-justified-container {
    padding: 15px 0; }
  .panel.panel-box.info-box i {
    line-height: 70px; }
  .panel.panel-box ul.list-justified {
    display: table;
    width: 100%;
    list-style: none;
    padding: 0; }
    .panel.panel-box ul.list-justified > li {
      float: none;
      display: table-cell;
      padding: 10px;
      width: 1%;
      border-right: 1px solid #eee; }
      .panel.panel-box ul.list-justified > li:last-child {
        border: none; }
      .panel.panel-box ul.list-justified > li p {
        margin: 0; }
  .panel.panel-box .panel-icon, .panel.panel-box .panel-img {
    display: block;
    margin: -75px auto 0;
    border-radius: 50%;
    border: 10px solid #fff;
    width: 150px;
    height: 150px;
    line-height: 80px;
    text-align: center;
    font-size: 58px;
    text-shadow: -6px 8px 5px rgba(0, 0, 0, 0.3); }
  .panel.panel-box .panel-icon {
    padding: 28px 35px 35px; }
  .panel.panel-box .panel-img {
    padding: 0; }
    .panel.panel-box .panel-img img {
      width: 100%;
      max-width: 100%; }
.panel.mini-box {
  min-height: 120px;
  padding: 25px; }
  .panel.mini-box .box-icon {
    display: block;
    float: left;
    margin: 0 15px 10px 0;
    width: 70px;
    height: 70px;
    line-height: 70px;
    vertical-align: middle;
    text-align: center;
    font-size: 35px;
    border-radius: 4px; }
    .panel.mini-box .box-icon.rounded {
      border-radius: 50%; }
  .panel.mini-box .btn-icon-lined {
    float: left;
    margin: 0 15px 10px 0;
    font-size: 32px; }
  .panel.mini-box .box-info p {
    margin: 0; }
.panel .panel-profile {
  border: none; }
  .panel .panel-profile .profile {
    margin: 5px 15px 5px 5px;
    border-radius: 50%;
    padding: 5px;
    border: 1px solid rgba(0, 0, 0, 0.2); }
    .panel .panel-profile .profile img {
      border-radius: 50%; }
  .panel .panel-profile .list-group > li > i {
    margin-right: 10px;
    font-size: 16px;
    color: #777;
    table-layout: fixed; }
  .panel .panel-profile .list-justified-container {
    padding: 15px 0; }
  .panel .panel-profile ul.list-justified {
    display: table;
    width: 100%;
    list-style: none;
    padding: 0; }
    .panel .panel-profile ul.list-justified > li {
      float: none;
      display: table-cell;
      padding: 10px;
      width: 1%;
      border-right: 1px solid #eee; }
      .panel .panel-profile ul.list-justified > li:last-child {
        border: none; }
      .panel .panel-profile ul.list-justified > li p {
        margin: 0; }

/*===================================================*\
 * 面板 king-block                                    *
\*===================================================*/
@media screen and (min-width: 1200px) {
  .king-block-content.king-block-content-narrow {
    padding-left: 10%;
    padding-right: 10%; } }
.side-content .king-block {
  -webkit-box-shadow: none;
  box-shadow: none; }

.king-block-table {
  width: 100%; }
  .king-block-table.td {
    padding: 10px;
    vertical-align: middle; }

.king-block {
  margin-bottom: 30px;
  background-color: #fff;
  -webkit-box-shadow: 0 2px rgba(0, 0, 0, 0.01);
  box-shadow: 0 2px rgba(0, 0, 0, 0.01); }
  .king-block.king-block-themed .king-block-header.king-default .king-block-title {
    color: #666; }
  .king-block.king-block-themed .king-block-header > .king-block-options > li > a, .king-block.king-block-themed .king-block-header button {
    color: #fff; }
  .king-block.king-block-themed > .king-block-header {
    border-bottom: none; }
    .king-block.king-block-themed > .king-block-header .king-block-title {
      color: #fff; }
      .king-block.king-block-themed > .king-block-header .king-block-title small {
        color: rgba(255, 255, 255, 0.75); }
    .king-block.king-block-themed > .king-block-header .king-block-options > li > span, .king-block.king-block-themed > .king-block-header .king-block-options > li button {
      color: #fff; }
  .king-block .king-block-header {
    padding: 7px 20px;
    -webkit-transition: opacity .2s ease-out;
    transition: opacity .2s ease-out;
    color: #646464; }
    .king-block .king-block-header::after {
      content: '.';
      display: block;
      height: 0;
      clear: both;
      visibility: hidden; }
    .king-block .king-block-header .king-block-options {
      float: right;
      margin: -3px 0 -3px 15px;
      padding: 0;
      height: 24px;
      list-style: none; }
      .king-block .king-block-header .king-block-options:before, .king-block .king-block-header .king-block-options:after {
        content: " ";
        display: table; }
      .king-block .king-block-header .king-block-options:after {
        clear: both; }
      .king-block .king-block-header .king-block-options.king-block-options-left {
        float: left;
        margin-right: 15px;
        margin-left: 0; }
        .king-block .king-block-header .king-block-options.king-block-options-left + .king-block-title {
          float: right; }
      .king-block .king-block-header .king-block-options > li {
        display: inline-block;
        margin: 0 2px;
        padding: 0; }
        .king-block .king-block-header .king-block-options > li > a, .king-block .king-block-header .king-block-options > li button {
          display: block;
          padding: 2px 3px;
          color: #999;
          opacity: .6; }
        .king-block .king-block-header .king-block-options > li > a:hover, .king-block .king-block-header .king-block-options > li button:hover {
          text-decoration: none;
          opacity: 1; }
        .king-block .king-block-header .king-block-options > li > a:active, .king-block .king-block-header .king-block-options > li button:active {
          opacity: 0.6; }
        .king-block .king-block-header .king-block-options > li > a:focus {
          text-decoration: none;
          opacity: 1; }
        .king-block .king-block-header .king-block-options > li > span {
          display: block;
          padding: 2px 3px; }
        .king-block .king-block-header .king-block-options > li button {
          background: none;
          border: none; }
        .king-block .king-block-header .king-block-options > li.active > a, .king-block .king-block-header .king-block-options > li.open > button {
          text-decoration: none;
          opacity: 1; }
  .king-block .king-block-title {
    font-size: 15px;
    font-weight: normal;
    line-height: 1.2; }
    .king-block .king-block-title.text-normal {
      text-transform: none; }
    .king-block .king-block-title small {
      font-size: 13px;
      font-weight: normal;
      text-transform: none; }
  .king-block .king-block-content {
    margin: 0 auto;
    padding: 20px;
    max-width: 100%;
    overflow-x: visible;
    -webkit-transition: opacity .2s ease-out;
    transition: opacity .2s ease-out; }
    .king-block .king-block-content .push, .king-block .king-block-content .king-block, .king-block .king-block-content .items-push > div {
      margin-bottom: 20px; }
    .king-block .king-block-content .items-push-2x > div {
      margin-bottom: 40px; }
    .king-block .king-block-content .items-push-3x > div {
      margin-bottom: 60px; }
    .king-block .king-block-content.king-block-content-full {
      padding-bottom: 20px; }
      .king-block .king-block-content.king-block-content-full .pull-b {
        margin-bottom: -20px; }
    .king-block .king-block-content .pull-b {
      margin-bottom: -1px; }
    .king-block .king-block-content.king-block-content-mini {
      padding-top: 10px; }
      .king-block .king-block-content.king-block-content-mini.king-block-content-full.king-block-content-mini {
        padding-bottom: 10px; }
    .king-block .king-block-content.tab-content {
      overflow: hidden; }
  .king-block.king-block-full .king-block-content {
    padding-bottom: 20px; }
    .king-block.king-block-full .king-block-content.king-block-content-mini {
      padding-bottom: 10px; }
  .king-block.king-block-bordered {
    -webkit-box-shadow: none;
    box-shadow: none; }
    .king-block.king-block-bordered .king-block-content {
      border: 1px solid #e9e9e9;
      border-top: none; }
    .king-block.king-block-bordered .king-block-header {
      border: 1px solid #e9e9e9; }
  .king-block.king-block-rounded {
    border-radius: 4px; }
    .king-block.king-block-rounded .king-block-header {
      border-top-right-radius: 3px;
      border-top-left-radius: 3px; }
    .king-block.king-block-rounded .king-block-content:first-child {
      border-top-right-radius: 3px;
      border-top-left-radius: 3px; }
    .king-block.king-block-rounded .king-block-content:last-child {
      border-bottom-right-radius: 3px;
      border-bottom-left-radius: 3px; }
  .king-block.king-block-transparent {
    background-color: transparent;
    -webkit-box-shadow: none;
    box-shadow: none; }
  .king-block.king-block-opt-refresh {
    position: relative; }
    .king-block.king-block-opt-refresh .king-block-header {
      opacity: .25; }
    .king-block.king-block-opt-refresh .king-block-content {
      opacity: .15; }
      .king-block.king-block-opt-refresh .king-block-content:after {
        position: absolute;
        top: 50%;
        left: 50%;
        margin: -20px 0 0 -20px;
        width: 40px;
        height: 36px;
        line-height: 36px;
        text-align: center;
        z-index: 999;
        content: " ";
        background-image: url(../images/loading_1_36x36.gif);
        background-repeat: no-repeat; }
  .king-block.king-block-opt-fullscreen {
    position: fixed;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    z-index: 1040;
    margin-bottom: 0;
    overflow-y: auto;
    -webkit-overflow-scrolling: touch;
    -webkit-backface-visibility: hidden;
    backface-visibility: hidden; }
  .king-block.king-block-opt-hidden.king-block-bordered .king-block-header {
    border-bottom: none; }
  .king-block.king-block-opt-hidden.king-block-opt-hidden .king-block-content {
    display: none; }
  .king-block > .nav-tabs {
    background-color: #f7f7f7;
    border-bottom: none;
    border-top: 1px solid #ddd;
    border-left: 1px solid #ddd;
    border-right: 1px solid #ddd; }
    .king-block > .nav-tabs.nav-tabs-right > li {
      float: right; }
    .king-block > .nav-tabs.nav-justified > li > a {
      margin-bottom: 0; }
    .king-block > .nav-tabs > li {
      margin-bottom: 0; }
      .king-block > .nav-tabs > li > a {
        margin-right: 0;
        padding-top: 7px;
        padding-bottom: 7px;
        color: #646464;
        font-weight: 600;
        border: 1px solid transparent;
        border-radius: 0; }
        .king-block > .nav-tabs > li > a:hover {
          color: #5c90d2;
          background-color: transparent;
          border-color: transparent; }
      .king-block > .nav-tabs > li.active > a {
        color: #646464;
        background-color: #fff;
        border-color: transparent; }
        .king-block > .nav-tabs > li.active > a:hover {
          color: #646464;
          background-color: #fff;
          border-color: transparent; }
        .king-block > .nav-tabs > li.active > a:focus {
          color: #646464;
          background-color: #fff;
          border-color: transparent; }
    .king-block > .nav-tabs.nav-tabs-alt {
      background-color: transparent;
      border-bottom: 1px solid #e9e9e9; }
      .king-block > .nav-tabs.nav-tabs-alt li.active {
        -webkit-box-shadow: 0 2px #5c90d2;
        box-shadow: 0 2px #5c90d2; }
  .king-block h1, .king-block h2, .king-block h3, .king-block h4, .king-block h5, .king-block h6 {
    padding: 0;
    margin: 0; }

a.king-block {
  display: block;
  color: #646464;
  font-weight: normal;
  -webkit-transition: all .15s ease-out;
  transition: all 0.15s ease-out; }
a:hover {
  color: #646464;
  opacity: .9; }
a.king-block-link-hover1:hover {
  -webkit-box-shadow: 0 2px rgba(0, 0, 0, 0.1);
  box-shadow: 0 2px rgba(0, 0, 0, 0.1);
  opacity: 1; }
a.king-block-link-hover1:active {
  -webkit-box-shadow: 0 2px rgba(0, 0, 0, 0.01);
  box-shadow: 0 2px rgba(0, 0, 0, 0.01); }
a.king-block-link-hover2:hover {
  -webkit-transform: translateY(-2px);
  -ms-transform: translateY(-2px);
  transform: translateY(-2px);
  -webkit-box-shadow: 0 2px 2px rgba(0, 0, 0, 0.1);
  box-shadow: 0 2px 2px rgba(0, 0, 0, 0.1);
  opacity: 1; }
a.king-block-link-hover2:active {
  -webkit-transform: translateY(-1px);
  -ms-transform: translateY(-1px);
  transform: translateY(-1px);
  -webkit-box-shadow: 0 2px 2px rgba(0, 0, 0, 0.05);
  box-shadow: 0 2px 2px rgba(0, 0, 0, 0.05); }
a.king-block-link-hover3:hover {
  -webkit-box-shadow: 0 0 12px rgba(0, 0, 0, 0.1);
  box-shadow: 0 0 12px rgba(0, 0, 0, 0.1);
  opacity: 1; }
a.king-block-link-hover3:active {
  -webkit-box-shadow: 0 0 2px rgba(0, 0, 0, 0.1);
  box-shadow: 0 0 2px rgba(0, 0, 0, 0.1); }

.ie9 .king-block.king-block-opt-refresh:after {
  content: "Loading.."; }

.king-block-options {
  float: right;
  margin: -3px 0 -3px 15px;
  padding: 0;
  height: 24px;
  list-style: none; }
  .king-block-options:before {
    content: " ";
    display: table; }
  .king-block-options:after {
    content: " ";
    display: table;
    clear: both; }
  .king-block-options.king-block-options-left {
    float: left;
    margin-right: 15px;
    margin-left: 0; }
  .king-block-options > li {
    display: inline-block;
    margin: 0 2px;
    padding: 0; }
    .king-block-options > li > span {
      display: block;
      padding: 2px 3px; }
    .king-block-options > li > a,
    .king-block-options > li > button {
      display: block;
      padding: 2px 3px;
      color: #999;
      opacity: .6;
      background: none;
      border: none; }
      .king-block-options > li > a:hover,
      .king-block-options > li > button:hover {
        text-decoration: none;
        opacity: 1; }
      .king-block-options > li > a:active,
      .king-block-options > li > button:active {
        opacity: .6; }

.king-panel-info {
  background: #4A9BFF;
  color: #FFF; }

.king-panel-primary {
  background: #5C90D2;
  color: #FFF; }

.king-panel-success {
  background: #46C37B;
  color: #FFF; }

.king-panel-warning {
  background: #f0a63a;
  color: #FFF; }

.king-panel-danger {
  background: #c94d3c;
  color: #FFF; }

.king-btn {
  min-width: 90px;
  display: inline-block;
  white-space: nowrap;
  outline: none;
  cursor: pointer;
  padding: 6px 10px;
  text-align: center;
  line-height: 16px;
  vertical-align: middle;
  font-size: 12px;
  background: defaultBgColor;
  border: 1px solid #eee;
  color: #555; }
  .king-btn:hover {
    background-color: #e1e1e1;
    text-decoration: none;
    color: #555; }
  .king-btn.king-disabled {
    background-color: #f5f5f5;
    border-color: #e9e9e9; }
  .king-btn.king-noborder {
    border: none !important; }
  .king-btn.king-radius {
    border-radius: 2px; }
  .king-btn.king-round {
    border-radius: 20px; }
  .king-btn.king-minw {
    min-width: 110px; }
  .king-btn.king-btn-mini {
    padding: 1px 5px;
    min-width: 50px; }
  .king-btn.king-btn-small {
    padding: 3px 10px;
    min-width: 70px; }
  .king-btn.king-btn-large {
    padding: 10px 16px;
    min-width: 120px;
    font-size: 16px; }
  .king-btn.king-default {
    border-color: #ddd;
    color: #555; }
  .king-btn.king-default:hover {
    background-color: #ddd; }
  .king-btn.king-default.king-disabled, .king-btn.king-default[disabled] {
    background-color: white;
    border-color: #ddd;
    opacity: .65; }
  .king-btn.king-default.king-border {
    background: none;
    border-color: #ddd;
    color: #555; }
    .king-btn.king-default.king-border.king-disabled, .king-btn.king-default.king-border[disabled] {
      opacity: .65;
      color: #626262;
      background: none;
      border-color: #eaeaea; }
    .king-btn.king-default.king-border:hover {
      color: #555;
      background-color: #ddd; }
  .king-btn.king-info {
    border-color: #2180F5;
    color: #fff; }
  .king-btn.king-info:hover {
    background-color: #2180F5; }
  .king-btn.king-info.king-disabled, .king-btn.king-info[disabled] {
    background-color: #64a9ff;
    border-color: #2180F5;
    opacity: .65; }
  .king-btn.king-info.king-border {
    background: none;
    border-color: #2180F5;
    color: #2180F5; }
    .king-btn.king-info.king-border.king-disabled, .king-btn.king-info.king-border[disabled] {
      opacity: .65;
      color: #398ef6;
      background: none;
      border-color: #398ef6; }
    .king-btn.king-info.king-border:hover {
      color: #fff;
      background-color: #4A9BFF; }
  .king-btn.king-primary {
    border-color: #3675c5;
    color: #fff; }
  .king-btn.king-primary:hover {
    background-color: #3675c5; }
  .king-btn.king-primary.king-disabled, .king-btn.king-primary[disabled] {
    background-color: #709ed8;
    border-color: #3675c5;
    opacity: .65; }
  .king-btn.king-primary.king-border {
    background: none;
    border-color: #3675c5;
    color: #3675c5; }
    .king-btn.king-primary.king-border.king-disabled, .king-btn.king-primary.king-border[disabled] {
      opacity: .65;
      color: #4882cd;
      background: none;
      border-color: #4882cd; }
    .king-btn.king-primary.king-border:hover {
      color: #fff;
      background-color: #5c90d2; }
  .king-btn.king-success {
    border-color: #34a263;
    color: #fff; }
  .king-btn.king-success:hover {
    background-color: #34a263; }
  .king-btn.king-success.king-disabled, .king-btn.king-success[disabled] {
    background-color: #54bf59;
    border-color: #34a263;
    opacity: .65; }
  .king-btn.king-success.king-border {
    background: none;
    border-color: #34a263;
    color: #34a263; }
    .king-btn.king-success.king-border.king-disabled, .king-btn.king-success.king-border[disabled] {
      opacity: .65;
      color: #3ab56f;
      background: none;
      border-color: #3ab56f; }
    .king-btn.king-success.king-border:hover {
      color: #fff;
      background-color: #44B549; }
  .king-btn.king-warning {
    border-color: #efa231;
    color: #fff; }
  .king-btn.king-warning:hover {
    background-color: #efa231; }
  .king-btn.king-warning.king-disabled, .king-btn.king-warning[disabled] {
    background-color: #f5c278;
    border-color: #efa231;
    opacity: .65; }
  .king-btn.king-warning.king-border {
    background: none;
    border-color: #efa231;
    color: #efa231; }
    .king-btn.king-warning.king-border.king-disabled, .king-btn.king-warning.king-border[disabled] {
      opacity: .65;
      color: #f1ad49;
      background: none;
      border-color: #f1ad49; }
    .king-btn.king-warning.king-border:hover {
      color: #fff;
      background-color: #f3b760; }
  .king-btn.king-danger {
    border-color: #c54736;
    color: #fff; }
  .king-btn.king-danger:hover {
    background-color: #c54736; }
  .king-btn.king-danger.king-disabled, .king-btn.king-danger[disabled] {
    background-color: #d87c70;
    border-color: #c54736;
    opacity: .65; }
  .king-btn.king-danger.king-border {
    background: none;
    border-color: #c54736;
    color: #c54736; }
    .king-btn.king-danger.king-border.king-disabled, .king-btn.king-danger.king-border[disabled] {
      opacity: .65;
      color: #cd5848;
      background: none;
      border-color: #cd5848; }
    .king-btn.king-danger.king-border:hover {
      color: #fff;
      background-color: #d26a5c; }
  .king-btn.king-disabled {
    cursor: default; }
  .king-btn.king-file-btn {
    overflow: hidden;
    position: relative; }
  .king-btn.king-file-btn input[type=file] {
    width: 150%;
    height: 100%;
    font-size: 300px;
    opacity: 0;
    filter: alpha(opacity=0);
    cursor: pointer;
    left: -40px;
    right: 0;
    bottom: 0;
    top: 0;
    position: absolute;
    padding: 0px;
    margin: 0px;
    overflow: hidden; }
  .king-btn.king-btn-icon {
    width: 30px;
    min-width: 30px;
    padding-left: 0;
    padding-right: 0; }
    .king-btn.king-btn-icon .btn-icon {
      margin-right: 0; }
    .king-btn.king-btn-icon.king-btn-mini {
      width: 24px;
      min-width: 24px; }
    .king-btn.king-btn-icon.king-btn-small {
      width: 28px;
      min-width: 28px; }
    .king-btn.king-btn-icon.king-btn-large {
      width: 38px;
      min-width: 38px; }
  .king-btn .btn-icon {
    margin-right: 5px; }

.king-btn-group {
  margin-right: 1px;
  display: inline-block; }
  .king-btn-group .king-btn {
    float: left;
    margin-left: -1px; }
  .king-btn-group .king-round {
    border-radius: 0; }
    .king-btn-group .king-round:first-child {
      border-radius: 20px 0 0 20px; }
    .king-btn-group .king-round:last-child {
      border-radius: 0 20px 20px 0; }
  .king-btn-group .king-radius {
    border-radius: 0; }
    .king-btn-group .king-radius:first-child {
      border-radius: 2px 0 0 2px; }
    .king-btn-group .king-radius:last-child {
      border-radius: 0 2px 2px 0; }
  .king-btn-group:after {
    content: '.';
    display: block;
    height: 0;
    clear: both;
    visibility: hidden; }
  .king-btn-group.king-btn-justified {
    display: table;
    width: 100%;
    table-layout: fixed;
    border-collapse: separate; }
    .king-btn-group.king-btn-justified .king-btn {
      display: table-cell;
      float: none;
      width: 100%; }

/*===================================================*\
 * widget1
\*===================================================*/
.king-widget1 {
  position: relative;
  padding: 15px;
  background: #fff;
  border: 1px solid #ddd;
  color: #5b5b5b; }
  .king-widget1 .fa-stack {
    font-size: 30px;
    border-radius: 50%; }
    .king-widget1 .fa-stack i.success {
      color: #5cb85c; }
    .king-widget1 .fa-stack i.danger {
      color: #de3431; }
    .king-widget1 .fa-stack i.info {
      color: #428bca; }
    .king-widget1 .fa-stack i.warning {
      color: #ffce00; }
  .king-widget1 .icon-wrap {
    float: left;
    margin-right: 15px; }
  .king-widget1 .text-wrap h3 {
    padding: 0;
    margin: 5px 0;
    font-weight: 600;
    font-size: 20px;
    display: block;
    color: #4c5264; }
  .king-widget1 .progress.progress-xs {
    height: 5px;
    margin-top: 25px;
    margin-bottom: 20px;
    border-radius: 0;
    box-shadow: none; }
  .king-widget1.king-widget-info {
    background: #4A9BFF;
    color: #fff; }
  .king-widget1.king-widget-primary {
    background: #5c90d2;
    color: #fff; }
  .king-widget1.king-widget-success {
    background: #44B549;
    color: #fff; }
  .king-widget1.king-widget-warning {
    background: #f3b760;
    color: #fff; }
  .king-widget1.king-widget-danger {
    background: #d26a5c;
    color: #fff; }

/*===================================================*\
 * king-widget2
\*===================================================*/
.king-widget2 {
  line-height: 1.57142857;
  border-radius: 3px;
  background-color: #ffffff;
  color: #444;
  margin-bottom: 30px;
  position: relative; }
  .king-widget2 .cover {
    width: 100%; }
  .king-widget2 .widget-bordered {
    border: 1px solid #ddd; }
  .king-widget2 .king-widget2-title {
    margin-top: 0;
    color: #37474f;
    text-transform: capitalize;
    font-size: 22px; }
  .king-widget2 > .king-widget2-title {
    padding: 12px 20px; }
  .king-widget2 .king-widget2-header {
    border-radius: 3px 3px 0 0; }
    .king-widget2 .king-widget2-header:last-child {
      border-radius: inherit; }
  .king-widget2 .king-widget2-body {
    position: relative;
    padding: 30px 25px; }
    .king-widget2 .king-widget2-body:last-child {
      border-radius: 0 0 3px 3px; }
      .king-widget2 .king-widget2-body:last-child .king-widget2-body-footer {
        border-radius: 0 0 3px 3px; }
  .king-widget2 .king-widget2-footer {
    border-radius: 0 0 3px 3px;
    margin-top: 30px; }
    .king-widget2 .king-widget2-footer:first-child {
      border-radiu: inherit; }
    .king-widget2 .king-widget2-footer:before, .king-widget2 .king-widget2-footer:after {
      content: " ";
      display: table; }
    .king-widget2 .king-widget2-footer:after {
      clear: both; }
  .king-widget2 .king-widget2-content ul {
    margin: 0;
    padding: 0; }
  .king-widget2 .king-widget2-content li {
    list-style: none; }
  .king-widget2 .row.no-space {
    margin-left: 0px;
    margin-right: 0px; }
    .king-widget2 .row.no-space > [class*=col-] {
      padding-left: 0px;
      padding-right: 0px; }
  .king-widget2 .king-counter-number {
    font-weight: 300; }
  .king-widget2 .height-300 {
    height: 300px; }
  .king-widget2 .height-150 {
    height: 150px; }
  .king-widget2.king-widget-info {
    background: #4A9BFF;
    color: #fff; }
  .king-widget2.king-widget-primary {
    background: #5c90d2;
    color: #fff; }
  .king-widget2.king-widget-success {
    background: #44B549;
    color: #fff; }
  .king-widget2.king-widget-warning {
    background: #f3b760;
    color: #fff; }
  .king-widget2.king-widget-danger {
    background: #d26a5c;
    color: #fff; }

.king-widget2-metas {
  font-size: 12px; }
  .king-widget2-metas.type-link > a {
    position: relative;
    display: inline-block;
    padding: 3px 5px;
    color: #a3afb7; }
    .king-widget2-metas.type-link > a:first-child {
      padding-left: 0; }
    .king-widget2-metas.type-link > aa:hover {
      color: #ccd5db; }
    .king-widget2-metas.type-link > a + a:before {
      position: absolute;
      top: 10px;
      left: -2px;
      content: '';
      width: 3px;
      height: 3px;
      background-color: #a3afb7;
      border-radius: 50%; }

.king-widget2-actions {
  margin-top: 10px;
  text-align: right; }
  .king-widget2-actions a {
    display: inline-block;
    margin-right: 10px;
    vertical-align: middle;
    color: #a3afb7; }
    .king-widget2-actions a.icon, .king-widget2-actions a .icon {
      text-decoration: none; }
      .king-widget2-actions a.icon + span, .king-widget2-actions a .icon + span {
        margin-left: 2px; }
    .king-widget2-actions a.active, .king-widget2-actions a:hover, .king-widget2-actions a:focus {
      text-decoration: none;
      color: #ccd5db; }
    .king-widget2-actions a:last-child {
      margin-right: 0; }

.king-widget2-actions-sidebar {
  width: 60px;
  position: absolute;
  top: 20px;
  left: 20px; }
  .king-widget2-actions-sidebar a {
    display: inline-block;
    width: 100%;
    height: 60px;
    text-align: center;
    border-right: 1px solid #e4eaec;
    margin-right: 0; }
    .king-widget2-actions-sidebar a:before {
      display: inline-block;
      content: '';
      height: 100%;
      vertical-align: middle; }
    .king-widget2-actions-sidebar a + a {
      border-top: 1px solid #e4eaec; }
  .king-widget2-actions-sidebar + .king-widget2-content {
    margin-left: 80px; }

.king-widget2-watermark {
  position: absolute;
  opacity: 0.1;
  right: 0;
  bottom: 0;
  line-height: 1; }
  .king-widget2-watermark.darker {
    color: black; }
  .king-widget2-watermark.lighter {
    color: white; }

.king-widget2-left {
  position: absolute;
  width: 40%;
  height: 100%;
  top: 0;
  left: 0; }
  .king-widget2-left + .king-widget2-body {
    margin-left: 40%;
    width: 60%; }

@media (max-width: 767px) {
  .king-widget2-left {
    position: relative;
    width: 100%;
    height: 320px; }
    .king-widget2-left + .king-widget2-body {
      margin-left: 0;
      width: 100%; } }
.king-counter {
  text-align: center; }
  .king-counter > .king-counter-number, .king-counter .king-counter-number-group {
    font-size: 20px; }
  .king-counter .king-counter-label {
    display: block; }
  .king-counter .king-counter-icon {
    font-size: 20px; }

.king-counter-lg > .king-counter-number, .king-counter-lg .king-counter-number-group {
  font-size: 40px; }
.king-counter-lg .king-counter-icon {
  font-size: 40px; }

.king-counter-md > .king-counter-number, .king-counter-md .king-counter-number-group {
  font-size: 30px; }
.king-counter-md .king-counter-icon {
  font-size: 30px; }

.king-counter-sm > .king-counter-number, .king-counter-sm .king-counter-number-group {
  font-size: 14px; }
.king-counter-sm .king-counter-icon {
  font-size: 14px; }

.king-counter-sm .king-counter-number-related + .king-counter-number, .king-counter-sm .king-counter-number + .king-counter-number-related {
  margin-left: 0; }

.vertical-align {
  font-size: 0; }
  .vertical-align:before {
    display: inline-block;
    height: 100%;
    vertical-align: middle;
    content: ""; }
  .vertical-align .vertical-align-middle, .vertical-align .vertical-align-bottom {
    display: inline-block;
    max-width: 100%;
    font-size: 14px; }
  .vertical-align .vertical-align-middle {
    vertical-align: middle; }
  .vertical-align .vertical-align-bottom {
    vertical-align: bottom; }

.king-nav-boxed {
  box-shadow: 0 0 2px rgba(0, 0, 0, 0.2);
  background-color: #fff;
  border-radius: 4px; }
  .king-nav-boxed a {
    color: #333;
    text-decoration: none; }
  .king-nav-boxed.nav-justified > li > a {
    margin: 0; }
  .king-nav-boxed > li > a {
    display: block;
    padding: 10px 5px;
    border-left: 0;
    border-top: 1px solid #f3f3f3; }
    .king-nav-boxed > li > a i {
      display: block;
      width: 40px;
      height: 40px;
      line-height: 40px;
      margin: 0 auto 2px;
      font-size: 30px; }
  .king-nav-boxed > li:first-child > a {
    border-left: none;
    border-top: 0; }

.king-widget2-shadow {
  -webkit-box-shadow: 0 1px 1px rgba(0, 0, 0, 0.05);
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.05); }

.overlay-background .king-widget2-time {
  opacity: 0.8;
  color: #ffffff; }

.king-widget2-category {
  font-size: 16px; }

.king-widget2-divider:after {
  width: 20px;
  height: 2px;
  content: "";
  display: block;
  margin: 15px auto;
  background-color: #ffffff; }

@media (min-width: 768px) {
  .king-nav-boxed > li > a {
    border-top: 0;
    border-left: 1px solid #f3f3f3; } }
@media (min-width: 768px) {
  .king-nav-boxed > li:first-child > a {
    border-left: 1px solid #f3f3f3; } }
/*===================================================*\
 * king-widget2
\*===================================================*/
.king-card {
  max-height: 245px; }
  .king-card .king-colum-contain {
    display: block;
    overflow: hidden;
    background: #fff; }
  .king-card .king-colum-img {
    max-width: 100%; }
  .king-card .king-colum-desc {
    display: table; }
    .king-card .king-colum-desc .king-desc-contain {
      display: table-cell;
      vertical-align: top;
      max-height: 195px; }
      .king-card .king-colum-desc .king-desc-contain a {
        color: #0095eb; }
        .king-card .king-colum-desc .king-desc-contain a:hover {
          text-decoration: underline; }

/*===================================================*\
 *king-widget7
\*===================================================*/
.king-panel-item.king-panel-success {
  color: #FFF;
  text-align: center;
  color: #FFF; }
  .king-panel-item.king-panel-success .king-panel-left {
    height: 120px;
    float: left;
    padding: 30px 0;
    width: 30%;
    background: #44B549; }
  .king-panel-item.king-panel-success .king-panel-right {
    height: 120px;
    float: left;
    padding: 30px 0;
    width: 70%;
    background: #54bf59; }

.king-panel-item.king-panel-info {
  color: #FFF;
  text-align: center;
  color: #FFF; }
  .king-panel-item.king-panel-info .king-panel-left {
    height: 120px;
    float: left;
    padding: 30px 0;
    width: 30%;
    background: #4A9BFF; }
  .king-panel-item.king-panel-info .king-panel-right {
    height: 120px;
    float: left;
    padding: 30px 0;
    width: 70%;
    background: #64a9ff; }

.king-panel-item.king-panel-primary {
  color: #FFF;
  text-align: center;
  color: #FFF; }
  .king-panel-item.king-panel-primary .king-panel-left {
    height: 120px;
    float: left;
    padding: 30px 0;
    width: 30%;
    background: #5c90d2; }
  .king-panel-item.king-panel-primary .king-panel-right {
    height: 120px;
    float: left;
    padding: 30px 0;
    width: 70%;
    background: #709ed8; }

.king-panel-item.king-panel-warning {
  color: #FFF;
  text-align: center;
  color: #FFF; }
  .king-panel-item.king-panel-warning .king-panel-left {
    height: 120px;
    float: left;
    padding: 30px 0;
    width: 30%;
    background: #f3b760; }
  .king-panel-item.king-panel-warning .king-panel-right {
    height: 120px;
    float: left;
    padding: 30px 0;
    width: 70%;
    background: #f5c278; }

.king-panel-item.king-panel-danger {
  color: #FFF;
  text-align: center;
  color: #FFF; }
  .king-panel-item.king-panel-danger .king-panel-left {
    height: 120px;
    float: left;
    padding: 30px 0;
    width: 30%;
    background: #d26a5c; }
  .king-panel-item.king-panel-danger .king-panel-right {
    height: 120px;
    float: left;
    padding: 30px 0;
    width: 70%;
    background: #d87c70; }

/*===================================================*\
 *king-widget8
\*===================================================*/
.king-widget8 {
  border: 1px solid #ddd; }
  .king-widget8 .widget-item {
    margin-bottom: 10px; }
    .king-widget8 .widget-item strong {
      color: #444;
      vertical-align: middle; }
    .king-widget8 .widget-item .widget-icon {
      width: 13px;
      height: 13px;
      display: inline-block;
      vertical-align: middle;
      margin-right: 5px; }

.king-widget3.king-widget-info {
  background: #4A9BFF;
  color: #fff; }
.king-widget3.king-widget-primary {
  background: #5c90d2;
  color: #fff; }
.king-widget3.king-widget-success {
  background: #44B549;
  color: #fff; }
.king-widget3.king-widget-warning {
  background: #f3b760;
  color: #fff; }
.king-widget3.king-widget-danger {
  background: #d26a5c;
  color: #fff; }

.king-width-100 {
  width: 100%; }

/*===================================================*\
 *king-widget9
\*===================================================*/
.king-widget9 {
  display: table;
  width: 100%;
  table-layout: fixed;
  border-collapse: separate;
  background: #393939;
  color: #fff;
  padding: 55px 0; }
  .king-widget9 .king-widget9-content {
    margin: 0 auto;
    display: table-cell;
    float: none;
    border-right: 3px solid #2d2d2d;
    padding: 0; }
    .king-widget9 .king-widget9-content > div {
      width: 275px;
      margin: 0 auto; }
  .king-widget9 .king-icon-wrap {
    float: right;
    text-align: center; }
    .king-widget9 .king-icon-wrap span {
      display: inline-block;
      width: 86px;
      height: 86px;
      border-radius: 50%;
      line-height: 86px; }
      .king-widget9 .king-icon-wrap span i {
        width: 100%;
        text-align: center;
        vertical-align: middle;
        font-size: 38px;
        margin: 0; }
    .king-widget9 .king-icon-wrap h5 {
      font-size: 16px;
      font-weight: normal;
      margin: 20px 0 0 0; }
  .king-widget9 .king-text-wrap {
    float: left; }
    .king-widget9 .king-text-wrap h2 {
      margin: 0 0 25px 0;
      font-weight: normal;
      font-size: 30px; }
  .king-widget9 .text-wrap {
    display: inline-block;
    text-align: left; }
    .king-widget9 .text-wrap .text-wrap-left {
      float: left;
      margin-right: 20px;
      font-size: 12px; }
    .king-widget9 .text-wrap .text-wrap-right {
      float: right;
      font-size: 12px; }
    .king-widget9 .text-wrap p {
      margin: 0; }
  .king-widget9 .king-widget9-content:last-child {
    border: 0; }
  .king-widget9 .king-widget-info {
    background: #4A9BFF;
    color: #fff; }
  .king-widget9 .king-widget-primary {
    background: #5c90d2;
    color: #fff; }
  .king-widget9 .king-widget-success {
    background: #44B549;
    color: #fff; }
  .king-widget9 .king-widget-warning {
    background: #f3b760;
    color: #fff; }
  .king-widget9 .king-widget-danger {
    background: #d26a5c;
    color: #fff; }

/*===================================================*\ 
 * 时间轴 timeline
\*===================================================*/
.king-timeline {
  position: relative;
  margin: 0 0 30px 0;
  padding: 0;
  list-style: none; }
  .king-timeline:before {
    content: '';
    position: absolute;
    top: 0px;
    bottom: 0;
    width: 4px;
    background: #ddd;
    left: 31px;
    margin: 0;
    border-radius: 2px; }
  .king-timeline > li {
    position: relative;
    margin-right: 10px;
    margin-bottom: 15px; }
    .king-timeline > li:before, .king-timeline > li:after {
      content: " ";
      display: table; }
    .king-timeline > li:after {
      clear: both; }
    .king-timeline > li .king-timeline-item {
      margin-top: 0px;
      background: #fff;
      color: #444;
      margin-left: 60px;
      margin-right: 15px;
      padding: 0;
      position: relative; }
      .king-timeline > li .king-timeline-item > .time {
        color: #999;
        float: right;
        padding: 10px;
        font-size: 12px; }
      .king-timeline > li .king-timeline-item .king-timeline-header {
        margin: 0;
        color: #555;
        border-bottom: 1px solid #eee;
        padding: 10px;
        font-size: 14px;
        line-height: 1.1; }
        .king-timeline > li .king-timeline-item .king-timeline-header > a {
          font-weight: 600; }
      .king-timeline > li .king-timeline-item > .king-timeline-body, .king-timeline > li .king-timeline-item .king-timeline-footer {
        padding: 10px; }
    .king-timeline > li span {
      font-weight: 600;
      padding: 5px;
      display: inline-block;
      background-color: #fff;
      border-radius: 4px;
      color: #fff;
      border-radius: 0;
      font-weight: normal; }
    .king-timeline > li > .fa, .king-timeline > li .glyphicon, .king-timeline > li .ion {
      width: 30px;
      height: 30px;
      font-size: 15px;
      line-height: 30px;
      position: absolute;
      color: #fff;
      background: #d2d6de;
      border-radius: 50%;
      text-align: center;
      left: 18px;
      top: 0; }

/*===================================================*\ 
 * 时间轴 king-timeline3
\*===================================================*/
.king-timeline-wrap {
  width: 50%;
  float: left; }

.king-timeline3 {
  padding: 0px;
  margin: 20px;
  list-style: none;
  position: relative; }
  .king-timeline3:after {
    position: absolute;
    top: 0;
    left: 50%;
    width: 2px;
    margin-left: -1px;
    height: 100%;
    content: "";
    background: #e0e0e0; }
  .king-timeline3 .row {
    margin: 0px; }
  .king-timeline3 .timeline-item {
    padding-left: 0;
    list-style: none;
    margin-bottom: 0;
    position: relative; }
  .king-timeline3 .timeline.right {
    margin-top: 80px; }
  .king-timeline3 .timeline > li {
    position: relative;
    min-height: 144px; }
    .king-timeline3 .timeline > li.timeline-body:after {
      right: 100%;
      border: solid transparent;
      content: " ";
      height: 0;
      width: 0;
      position: absolute;
      pointer-events: none;
      border-color: transparent;
      border-width: 10px;
      top: 15px; }
  .king-timeline3 .timeline .timeline-icon {
    width: 50px;
    height: 50px;
    font-size: 17px;
    line-height: 50px;
    -webkit-font-smoothing: antialiased;
    position: absolute;
    color: #707980;
    background: #e0e0e0;
    border-radius: 50%;
    text-align: center;
    left: 6%;
    top: 0;
    margin: 0 0 0 -22px;
    padding: 0;
    z-index: 1; }
  .king-timeline3 .timeline .timeline.left .timeline-icon {
    left: auto;
    right: 0;
    margin: 0;
    margin-right: -40px; }
  .king-timeline3 .timeline .timeline.left .timeline-body {
    margin: 0 5% 20px 0; }
    .king-timeline3 .timeline .timeline.left .timeline-body:after {
      left: 100%;
      right: auto;
      border-top: 10px solid transparent;
      border-bottom: 10px solid transparent;
      border-right-color: transparent !important; }
  .king-timeline3 .timeline .timeline.right .timeline-icon {
    margin: 0;
    left: 0;
    margin-left: -40px; }
  .king-timeline3 .timeline .timeline.right .timeline-body {
    margin: 0 0 20px 5%; }
  .king-timeline3 .timeline .timeline.right .timeline-six .timeline-body {
    border-color: #FCC900;
    background-color: #FCC900; }
    .king-timeline3 .timeline .timeline.right .timeline-six .timeline-body:after {
      border-right-color: #FCC900; }
  .king-timeline3 .timeline .success .timeline-body {
    background-color: #44B549;
    border-color: #44B549; }
    .king-timeline3 .timeline .success .timeline-body:after {
      border-left-color: #44B549; }
  .king-timeline3 .timeline .warning .timeline-body {
    background-color: #f3b760;
    border-color: #f3b760; }
    .king-timeline3 .timeline .warning .timeline-body:after {
      border-left-color: #f3b760; }
  .king-timeline3 .timeline .danger .timeline-body {
    background-color: #d26a5c;
    border-color: #d26a5c; }
    .king-timeline3 .timeline .danger .timeline-body:after {
      border-left-color: #d26a5c; }
  .king-timeline3 .timeline .info .timeline-body {
    background-color: #4A9BFF;
    border-color: #4A9BFF; }
    .king-timeline3 .timeline .info .timeline-body:after {
      border-left-color: #4A9BFF; }
  .king-timeline3 .timeline .primary .timeline-body {
    background-color: #5c90d2;
    border-color: #5c90d2; }
    .king-timeline3 .timeline .primary .timeline-body:after {
      border-left-color: #5c90d2; }
  .king-timeline3 .timeline-body {
    margin: 0 0 20px 14%;
    padding: 20px;
    color: #fff;
    position: relative;
    border-width: 2px;
    border-style: solid;
    border-radius: 3px;
    background-color: #fff; }

/*===================================================*\ 
 * 时间轴样式二
\*===================================================*/
.king-timeline-simple {
  width: 100%;
  margin: 0px;
  padding: 0px;
  list-style: none;
  overflow: hidden; }
  .king-timeline-simple li {
    float: left;
    width: 100%;
    position: relative;
    padding: 15px 0px;
    padding-left: 50px !important; }
    .king-timeline-simple li:before {
      content: " ";
      position: absolute;
      height: 100%;
      width: 3px;
      background: #e7ebf1;
      left: 25px;
      top: 0px;
      z-index: 1; }
    .king-timeline-simple li:after {
      content: " ";
      position: absolute;
      z-index: 2;
      width: 15px;
      height: 15px;
      border: 2px solid #FFF;
      -webkit-border-top-right-radius: 50%;
      -webkit-border-bottom-right-radius: 0;
      -webkit-border-bottom-left-radius: 0;
      -webkit-border-top-left-radius: 0;
      -moz-border-radius-topright: 50%;
      -moz-border-radius-bottomright: 0;
      -moz-border-radius-bottomleft: 0;
      -moz-border-radius-topleft: 0;
      border-top-right-radius: 50%;
      border-bottom-right-radius: 0;
      border-bottom-left-radius: 0;
      border-top-left-radius: 0;
      -moz-background-clip: padding-box;
      -webkit-background-clip: padding-box;
      background-clip: padding-box;
      -moz-border-radius: 50%;
      -webkit-border-radius: 50%;
      border-radius: 50%;
      background: #e7ebf1;
      left: 19px;
      top: 50%;
      margin-top: -7.5px; }
    .king-timeline-simple li .timeline-simple-date {
      display: inline-block;
      width: 100%;
      margin-bottom: 5px;
      font-size: 11px;
      color: #999999; }
    .king-timeline-simple li .timeline-simple-wrap {
      float: left;
      padding: 10px;
      border: 1px solid #ddd;
      -webkit-border-top-right-radius: 5px;
      -webkit-border-bottom-right-radius: 0;
      -webkit-border-bottom-left-radius: 0;
      -webkit-border-top-left-radius: 0;
      -moz-border-radius-topright: 5px;
      -moz-border-radius-bottomright: 0;
      border-top-right-radius: 5px;
      border-bottom-right-radius: 0;
      -moz-border-radius-bottomleft: 0;
      -moz-border-radius-topleft: 0;
      border-bottom-left-radius: 0;
      border-top-left-radius: 0;
      -moz-background-clip: padding-box;
      position: relative;
      background: #FFF;
      -webkit-background-clip: padding-box;
      background-clip: padding-box;
      -moz-border-radius: 5px;
      -webkit-border-radius: 5px;
      border-radius: 5px;
      -webkit-transition: all 200ms ease;
      -moz-transition: all 200ms ease;
      -ms-transition: all 200ms ease;
      -o-transition: all 200ms ease;
      transition: all 200ms ease; }
      .king-timeline-simple li .timeline-simple-wrap:after, .king-timeline-simple li .timeline-simple-wrap:before {
        right: 100%;
        top: 50%;
        border: solid transparent;
        content: " ";
        height: 0;
        width: 0;
        position: absolute;
        pointer-events: none;
        -webkit-transition: all 200ms ease;
        -moz-transition: all 200ms ease;
        -ms-transition: all 200ms ease;
        -o-transition: all 200ms ease;
        transition: all 200ms ease; }
      .king-timeline-simple li .timeline-simple-wrap:after {
        border-color: rgba(255, 255, 255, 0);
        border-right-color: #FFF;
        border-width: 5px;
        margin-top: -5px; }
      .king-timeline-simple li .timeline-simple-wrap:before {
        border-color: rgba(221, 221, 221, 0);
        border-right-color: #ddd;
        border-width: 6px;
        margin-top: -6px; }
      .king-timeline-simple li .timeline-simple-wrap:hover {
        background: #F5F5F5; }
        .king-timeline-simple li .timeline-simple-wrap:hover :after {
          border-right-color: #F5F5F5; }
    .king-timeline-simple li.primary:after {
      background: #5c90d2 !important; }
    .king-timeline-simple li.primary .timeline-simple-wrap {
      background: #5c90d2;
      border-color: #5c90d2;
      color: #fff; }
      .king-timeline-simple li.primary .timeline-simple-wrap .timeline-simple-date {
        color: #fff;
        text-align: right;
        margin-top: 5px;
        margin-bottom: 0px; }
      .king-timeline-simple li.primary .timeline-simple-wrap:after, .king-timeline-simple li.primary .timeline-simple-wrap:before {
        border-right-color: #5c90d2; }
      .king-timeline-simple li.primary .timeline-simple-wrap:hover {
        background: #3675c5;
        border-color: #3675c5; }
    .king-timeline-simple li.info:after {
      background: #4A9BFF !important; }
    .king-timeline-simple li.info .timeline-simple-wrap {
      background: #4A9BFF;
      border-color: #4A9BFF;
      color: #fff; }
      .king-timeline-simple li.info .timeline-simple-wrap .timeline-simple-date {
        color: #fff;
        text-align: right;
        margin-top: 5px;
        margin-bottom: 0px; }
      .king-timeline-simple li.info .timeline-simple-wrap:after, .king-timeline-simple li.info .timeline-simple-wrap:before {
        border-right-color: #4A9BFF; }
      .king-timeline-simple li.info .timeline-simple-wrap:hover {
        background: #177fff;
        border-color: #177fff; }
    .king-timeline-simple li.success:after {
      background: #44B549 !important; }
    .king-timeline-simple li.success .timeline-simple-wrap {
      background: #44B549;
      border-color: #44B549;
      color: #fff; }
      .king-timeline-simple li.success .timeline-simple-wrap .timeline-simple-date {
        color: #fff;
        text-align: right;
        margin-top: 5px;
        margin-bottom: 0px; }
      .king-timeline-simple li.success .timeline-simple-wrap:after, .king-timeline-simple li.success .timeline-simple-wrap:before {
        border-right-color: #44B549; }
      .king-timeline-simple li.success .timeline-simple-wrap:hover {
        background: #36903a;
        border-color: #36903a; }
    .king-timeline-simple li.warning:after {
      background: #efa231 !important; }
    .king-timeline-simple li.warning .timeline-simple-wrap {
      background: #efa231;
      border-color: #efa231;
      color: #fff; }
      .king-timeline-simple li.warning .timeline-simple-wrap .timeline-simple-date {
        color: #fff;
        text-align: right;
        margin-top: 5px;
        margin-bottom: 0px; }
      .king-timeline-simple li.warning .timeline-simple-wrap:after, .king-timeline-simple li.warning .timeline-simple-wrap:before {
        border-right-color: #efa231; }
      .king-timeline-simple li.warning .timeline-simple-wrap:hover {
        background: #dc8a11;
        border-color: #dc8a11; }
    .king-timeline-simple li.danger:after {
      background: #c54736 !important; }
    .king-timeline-simple li.danger .timeline-simple-wrap {
      background: #c54736;
      border-color: #c54736;
      color: #fff; }
      .king-timeline-simple li.danger .timeline-simple-wrap .timeline-simple-date {
        color: #fff;
        text-align: right;
        margin-top: 5px;
        margin-bottom: 0px; }
      .king-timeline-simple li.danger .timeline-simple-wrap:after, .king-timeline-simple li.danger .timeline-simple-wrap:before {
        border-right-color: #c54736; }
      .king-timeline-simple li.danger .timeline-simple-wrap:hover {
        background: #9d392b;
        border-color: #9d392b; }

/*===================================================*\ 
 * 时间轴三 timeline3 2016-1-19
\*===================================================*/
.king-timeline-3 {
  width: 580px;
  position: relative;
  margin: 0 0 30px 0;
  padding: 0;
  list-style: none; }
  .king-timeline-3:before {
    content: '';
    position: absolute;
    top: 0px;
    bottom: 0;
    width: 3px;
    background: #2e88c5;
    opacity: 0.4;
    left: 50%;
    margin: 0;
    padding-bottom: 30px;
    border-radius: 2px; }
  .king-timeline-3 > li {
    position: relative;
    margin-bottom: 15px; }
    .king-timeline-3 > li:before, .king-timeline-3 > li:after {
      content: " ";
      display: table; }
    .king-timeline-3 > li:after {
      clear: both; }
    .king-timeline-3 > li span {
      padding: 5px;
      display: inline-block;
      background-color: #fff; }
    .king-timeline-3 > li .king-timeline-title {
      height: 40px;
      font: 500 34px 'Impact';
      color: #5c90d2;
      opacity: 0.4;
      border-bottom: 1px solid #2e88c5; }
    .king-timeline-3 > li .king-timeline-title-last {
      height: 40px; }
    .king-timeline-3 > li .king-timeline-item-3 .king-timeline-body {
      margin: 10px 0;
      font: 400 16px '微软雅黑';
      color: #2e88c5; }
    .king-timeline-3 > li .king-timepoint {
      display: block;
      position: absolute;
      margin-left: auto;
      top: 30px;
      width: 22px;
      height: 22px;
      border: 4px solid #fff;
      border-radius: 50%;
      -moz-border-radius: 50%;
      -webkit-border-radius: 50%; }
    .king-timeline-3 > li .king-timepoint-complete {
      background-color: #2e88c5; }
    .king-timeline-3 > li .king-timepoint-undone {
      background-color: #acd5fe; }
    .king-timeline-3 > li:first-child {
      width: 100%;
      text-align: center;
      margin-left: auto;
      margin-right: auto; }
      .king-timeline-3 > li:first-child .king-bg-font {
        font: 400 24px '微软雅黑';
        color: #2e88c5; }
    .king-timeline-3 > li:nth-child(2n+2) {
      margin: 10px 10px 15px 281px; }
      .king-timeline-3 > li:nth-child(2n+2) .king-timeline-title {
        margin-left: 24px;
        text-align: right; }
      .king-timeline-3 > li:nth-child(2n+2) .king-timeline-item-3 {
        text-align: right; }
      .king-timeline-3 > li:nth-child(2n+2) .king-timepoint {
        margin-right: auto; }
    .king-timeline-3 > li:nth-child(2n+3) {
      text-align: right;
      margin: 10px 281px 15px 10px; }
      .king-timeline-3 > li:nth-child(2n+3) .king-timeline-title {
        text-align: left;
        margin-right: 16px; }
      .king-timeline-3 > li:nth-child(2n+3) .king-timeline-item-3 {
        text-align: left; }
      .king-timeline-3 > li:nth-child(2n+3) .king-timepoint {
        margin-right: -4px;
        right: 0; }
  .king-timeline-3.primary:before {
    background: #5c90d2 !important; }
  .king-timeline-3.primary:after {
    background: #5c90d2 !important; }
  .king-timeline-3.primary > li .king-timeline-title {
    color: #BED2ED !important;
    opacity: 0.4;
    border-bottom: 1px solid #BED2ED !important; }
  .king-timeline-3.primary > li .king-timeline-item-3 .king-timeline-body {
    color: #BED2ED !important; }
  .king-timeline-3.primary > li .king-timepoint-complete {
    background-color: #5c90d2 !important; }
  .king-timeline-3.primary > li .king-timepoint-undone {
    background-color: #BED2ED !important; }
  .king-timeline-3.primary > li:first-child .king-bg-font {
    color: #5c90d2 !important; }
  .king-timeline-3.info:before {
    background: #4A9BFF !important; }
  .king-timeline-3.info:after {
    background: #4A9BFF !important; }
  .king-timeline-3.info > li .king-timeline-title {
    color: #B6D7FF !important;
    opacity: 0.4;
    border-bottom: 1px solid #B6D7FF !important; }
  .king-timeline-3.info > li .king-timeline-item-3 .king-timeline-body {
    color: #B6D7FF !important; }
  .king-timeline-3.info > li .king-timepoint-complete {
    background-color: #4A9BFF !important; }
  .king-timeline-3.info > li .king-timepoint-undone {
    background-color: #B6D7FF !important; }
  .king-timeline-3.info > li:first-child .king-bg-font {
    color: #4A9BFF !important; }
  .king-timeline-3.success:before {
    background: #44B549 !important; }
  .king-timeline-3.success:after {
    background: #44B549 !important; }
  .king-timeline-3.success > li .king-timeline-title {
    color: #ADDAC0 !important;
    opacity: 0.4;
    border-bottom: 1px solid #ADDAC0 !important; }
  .king-timeline-3.success > li .king-timeline-item-3 .king-timeline-body {
    color: #ADDAC0 !important; }
  .king-timeline-3.success > li .king-timepoint-complete {
    background-color: #44B549 !important; }
  .king-timeline-3.success > li .king-timepoint-undone {
    background-color: #ADDAC0 !important; }
  .king-timeline-3.success > li:first-child .king-bg-font {
    color: #44B549 !important; }
  .king-timeline-3.warning:before {
    background: #f3b760 !important; }
  .king-timeline-3.warning:after {
    background: #f3b760 !important; }
  .king-timeline-3.warning > li .king-timeline-title {
    color: #F9DAAC !important;
    opacity: 0.4;
    border-bottom: 1px solid #F9DAAC !important; }
  .king-timeline-3.warning > li .king-timeline-item-3 .king-timeline-body {
    color: #F9DAAC !important; }
  .king-timeline-3.warning > li .king-timepoint-complete {
    background-color: #f3b760 !important; }
  .king-timeline-3.warning > li .king-timepoint-undone {
    background-color: #F9DAAC !important; }
  .king-timeline-3.warning > li:first-child .king-bg-font {
    color: #f3b760 !important; }
  .king-timeline-3.danger:before {
    background: #d26a5c !important; }
  .king-timeline-3.danger:after {
    background: #d26a5c !important; }
  .king-timeline-3.danger > li .king-timeline-title {
    color: #E8B5AE !important;
    opacity: 0.4;
    border-bottom: 1px solid #E8B5AE !important; }
  .king-timeline-3.danger > li .king-timeline-item-3 .king-timeline-body {
    color: #E8B5AE !important; }
  .king-timeline-3.danger > li .king-timepoint-complete {
    background-color: #d26a5c !important; }
  .king-timeline-3.danger > li .king-timepoint-undone {
    background-color: #E8B5AE !important; }
  .king-timeline-3.danger > li:first-child .king-bg-font {
    color: #d26a5c !important; }

.king-page-topbar {
  border-bottom: 1px solid #ddd;
  background: #fff; }
  .king-page-topbar .h1, .king-page-topbar .h2, .king-page-topbar .h3, .king-page-topbar h1, .king-page-topbar h2, .king-page-topbar h3 {
    margin-top: 0; }
  .king-page-topbar .breadcrumb {
    margin-bottom: 0;
    background: transparent; }
    .king-page-topbar .breadcrumb > li + li:before {
      content: "> " !important; }

/*===================================================*\
 * step1
\*===================================================*/
.king-justified-pearls.king-pearls {
  display: table;
  width: 100%;
  table-layout: fixed; }
  .king-justified-pearls.king-pearls .king-pearl {
    display: table-cell;
    width: 100%; }

.king-pearls {
  margin-bottom: 22px; }
  .king-pearls.row {
    display: block; }
  .king-pearls.king-pearls-lg .king-pearl:after,
  .king-pearls.king-pearls-lg .king-pearl:before {
    top: 20px; }
  .king-pearls.king-pearls-lg .king-pearl-title {
    font-size: 18px; }
  .king-pearls.king-pearls-lg .king-pearl-icon, .king-pearls.king-pearls-lg .king-pearl-number {
    width: 40px;
    height: 40px;
    line-height: 36px; }
  .king-pearls.king-pearls-lg .king-pearl-icon {
    font-size: 20px; }
  .king-pearls.king-pearls-lg .king-pearl-number {
    font-size: 20px; }
  .king-pearls.king-pearls-sm .king-pearl:after,
  .king-pearls.king-pearls-sm .king-pearl:before {
    top: 16px; }
  .king-pearls.king-pearls-sm .king-pearl-title {
    font-size: 14px; }
  .king-pearls.king-pearls-sm .king-pearl-icon, .king-pearls.king-pearls-sm .king-pearl-number {
    width: 32px;
    height: 32px;
    line-height: 28px; }
  .king-pearls.king-pearls-sm .king-pearl-icon {
    font-size: 16px; }
  .king-pearls.king-pearls-sm .king-pearl-number {
    font-size: 16px; }
  .king-pearls.king-pearls-xs .king-pearl:after,
  .king-pearls.king-pearls-xs .king-pearl:before {
    top: 12px;
    height: 2px; }
  .king-pearls.king-pearls-xs .king-pearl-title {
    font-size: 10px; }
  .king-pearls.king-pearls-xs .king-pearl-icon, .king-pearls.king-pearls-xs .king-pearl-number {
    width: 24px;
    height: 24px;
    line-height: 20px; }
  .king-pearls.king-pearls-xs .king-pearl-icon {
    font-size: 12px; }
  .king-pearls.king-pearls-xs .king-pearl-number {
    font-size: 12px; }

.king-pearl {
  position: relative;
  padding: 0;
  margin: 0;
  text-align: center; }
  .king-pearl:after, .king-pearl:before {
    position: absolute;
    top: 18px;
    z-index: 0;
    width: 50%;
    height: 4px;
    content: "";
    background-color: #CCC; }
  .king-pearl:before {
    left: 0; }
  .king-pearl:after {
    right: 0; }
  .king-pearl:first-child:before, .king-pearl:last-child:after {
    display: none !important; }
  .king-pearl .king-pearl-icon, .king-pearl .king-pearl-number {
    position: relative;
    z-index: 1;
    display: inline-block;
    width: 36px;
    height: 36px;
    line-height: 32px;
    color: #fff;
    text-align: center;
    background: #ccd5db;
    border-radius: 50%;
    border: 2px solid #ccd5db; }
  .king-pearl .king-pearl-number {
    font-size: 18px; }
  .king-pearl .king-pearl-icon {
    font-size: 18px; }
  .king-pearl .king-pearl-title {
    margin-top: .5em;
    display: block;
    font-size: 16px;
    color: #526069;
    margin-bottom: 0;
    overflow: hidden;
    text-overflow: ellipsis;
    word-wrap: normal;
    white-space: nowrap; }
  .king-pearl.current:after, .king-pearl.current:before {
    background-color: #62a8ea; }
  .king-pearl.current .king-pearl-icon, .king-pearl.current .king-pearl-number {
    color: #62a8ea;
    background-color: #fff;
    border-color: #62a8ea;
    -webkit-transform: scale(1.3);
    -ms-transform: scale(1.3);
    -o-transform: scale(1.3);
    transform: scale(1.3); }
  .king-pearl.disabled {
    pointer-events: none;
    cursor: auto; }
    .king-pearl.disabled:after, .king-pearl.disabled:before {
      background-color: #CCC; }
    .king-pearl.disabled .king-pearl-icon, .king-pearl.disabled .king-pearl-number {
      color: #fff;
      background-color: #ccd5db;
      border-color: #ccd5db; }
  .king-pearl.error:before {
    background-color: #62a8ea; }
  .king-pearl.error:after {
    background-color: #CCC; }
  .king-pearl.error .king-pearl-icon, .king-pearl.error .king-pearl-number {
    color: #f96868;
    background-color: #fff;
    border-color: #f96868; }
  .king-pearl.done:after, .king-pearl.done:before {
    background-color: #62a8ea; }
  .king-pearl.done .king-pearl-icon, .king-pearl.done .king-pearl-number {
    color: #fff;
    background-color: #62a8ea;
    border-color: #62a8ea; }

.king-pearl.king-pearls-info .done .king-pearl-number {
  background-color: #4A9BFF;
  border-color: #4A9BFF; }

/*===================================================*\
 * step2
\*===================================================*/
.king-step2 {
  text-align: center; }

.king-justified-process.king-process {
  display: table;
  table-layout: fixed;
  width: 100%; }
  .king-justified-process.king-process > div {
    display: table-cell;
    width: 100%; }

.king-process {
  height: 50px;
  display: inline-block;
  border-radius: 5px;
  color: #fff;
  text-align: center; }
  .king-process > div {
    height: 50px;
    line-height: 50px;
    padding: 0 30px;
    display: inline-block;
    position: relative;
    width: 200px; }
    .king-process > div:first-child {
      border-radius: 5px; }
  .king-process .step-hasnext:after, .king-process .step-hasnext:before {
    border: solid transparent;
    border-width: 25px;
    content: ' ';
    position: absolute;
    height: 0;
    right: -50px;
    top: 0px;
    width: 0;
    z-index: 1; }
  .king-process.king-process-info {
    background-color: #97c5ff; }
    .king-process.king-process-info .process-done {
      background-color: #4A9BFF; }
      .king-process.king-process-info .process-done.step-hasnext:before {
        border-left-color: #fff; }
      .king-process.king-process-info .process-done.step-hasnext:after {
        border-left-color: #4A9BFF;
        right: -48px; }
    .king-process.king-process-info .process-did.step-hasnext:before {
      border-left-color: #fff; }
    .king-process.king-process-info .process-did.step-hasnext:after {
      border-left-color: #97c5ff;
      right: -48px; }
  .king-process.king-process-primary {
    background-color: #98b9e3; }
    .king-process.king-process-primary .process-done {
      background-color: #5c90d2; }
      .king-process.king-process-primary .process-done.step-hasnext:before {
        border-left-color: #fff; }
      .king-process.king-process-primary .process-done.step-hasnext:after {
        border-left-color: #5c90d2;
        right: -48px; }
    .king-process.king-process-primary .process-did.step-hasnext:before {
      border-left-color: #fff; }
    .king-process.king-process-primary .process-did.step-hasnext:after {
      border-left-color: #98b9e3;
      right: -48px; }
  .king-process.king-process-warning {
    background-color: #f8d7a7; }
    .king-process.king-process-warning .process-done {
      background-color: #f3b760; }
      .king-process.king-process-warning .process-done.step-hasnext:before {
        border-left-color: #fff; }
      .king-process.king-process-warning .process-done.step-hasnext:after {
        border-left-color: #f3b760;
        right: -48px; }
    .king-process.king-process-warning .process-did.step-hasnext:before {
      border-left-color: #fff; }
    .king-process.king-process-warning .process-did.step-hasnext:after {
      border-left-color: #f8d7a7;
      right: -48px; }
  .king-process.king-process-danger {
    background-color: #e3a198; }
    .king-process.king-process-danger .process-done {
      background-color: #d26a5c; }
      .king-process.king-process-danger .process-done.step-hasnext:before {
        border-left-color: #fff; }
      .king-process.king-process-danger .process-done.step-hasnext:after {
        border-left-color: #d26a5c;
        right: -48px; }
    .king-process.king-process-danger .process-did.step-hasnext:before {
      border-left-color: #fff; }
    .king-process.king-process-danger .process-did.step-hasnext:after {
      border-left-color: #e3a198;
      right: -48px; }
  .king-process.king-process-success {
    background-color: #79cd7d; }
    .king-process.king-process-success .process-done {
      background-color: #44B549; }
      .king-process.king-process-success .process-done.step-hasnext:before {
        border-left-color: #fff; }
      .king-process.king-process-success .process-done.step-hasnext:after {
        border-left-color: #44B549;
        right: -48px; }
    .king-process.king-process-success .process-did.step-hasnext:before {
      border-left-color: #fff; }
    .king-process.king-process-success .process-did.step-hasnext:after {
      border-left-color: #79cd7d;
      right: -48px; }

/*===================================================*\
 * step3
\*===================================================*/
.king-step3 {
  text-align: center; }
  .king-step3 li {
    overflow: hidden;
    text-align: left; }
    .king-step3 li .step-num {
      float: left;
      width: 30px;
      height: 30px;
      line-height: 30px;
      border-radius: 50%;
      font-size: 15px;
      text-align: center;
      color: #aaa;
      border: 1px solid #aaa; }
    .king-step3 li .step-text {
      margin-left: 15px;
      float: left;
      position: relative;
      color: #999; }
      .king-step3 li .step-text h4 {
        margin: 5px 0 10px 0; }
      .king-step3 li .step-text:before {
        content: '';
        position: absolute;
        top: 35px;
        bottom: 5px;
        width: 1px;
        left: -30px;
        background: #e9e9e9; }
  .king-step3.king-step-info .process-done .step-num {
    color: #4A9BFF;
    border-color: #4A9BFF; }
  .king-step3.king-step-info .process-done .step-text:before {
    background-color: #4A9BFF; }
  .king-step3.king-step-info .process-doing .step-num {
    background-color: #4A9BFF;
    border-color: #4A9BFF;
    color: #fff !important; }
  .king-step3.king-step-primary .process-done .step-num {
    color: #5c90d2;
    border-color: #5c90d2; }
  .king-step3.king-step-primary .process-done .step-text:before {
    background-color: #5c90d2; }
  .king-step3.king-step-primary .process-doing .step-num {
    background-color: #5c90d2;
    border-color: #5c90d2;
    color: #fff !important; }
  .king-step3.king-step-warning .process-done .step-num {
    color: #f3b760;
    border-color: #f3b760; }
  .king-step3.king-step-warning .process-done .step-text:before {
    background-color: #f3b760; }
  .king-step3.king-step-warning .process-doing .step-num {
    background-color: #f3b760;
    border-color: #f3b760;
    color: #fff !important; }
  .king-step3.king-step-danger .process-done .step-num {
    color: #d26a5c;
    border-color: #d26a5c; }
  .king-step3.king-step-danger .process-done .step-text:before {
    background-color: #d26a5c; }
  .king-step3.king-step-danger .process-doing .step-num {
    background-color: #d26a5c;
    border-color: #d26a5c;
    color: #fff !important; }
  .king-step3.king-step-success .process-done .step-num {
    color: #44B549;
    border-color: #44B549; }
  .king-step3.king-step-success .process-done .step-text:before {
    background-color: #44B549; }
  .king-step3.king-step-success .process-doing .step-num {
    background-color: #44B549;
    border-color: #44B549;
    color: #fff !important; }

/*===================================================*\
 * 消息状态
\*===================================================*/
.king-notice-box {
  margin-left: 10px;
  padding: 10px;
  padding-left: 33px;
  text-align: left;
  display: inline-block; }
  .king-notice-box.king-notice-warning {
    background: url(../images/notice_warning_icon.png) no-repeat left center; }
  .king-notice-box.king-notice-success {
    background: url(../images/notice_success_icon.png) no-repeat left center; }
  .king-notice-box.king-notice-fail {
    background: url(../images/notice_fail_icon.png) no-repeat left center; }
  .king-notice-box.king-notice-question {
    background: url(../images/notice_question_icon.png) no-repeat left center; }
  .king-notice-box.king-notice-sad {
    background: url(../images/notice_sad_icon.png) no-repeat left center; }
  .king-notice-box.king-notice-happy {
    background: url(../images/notice_happy_icon.png) no-repeat left center; }
  .king-notice-box .king-notice-text {
    margin: 0;
    line-height: 30px;
    padding-left: 8px;
    min-width: 150px; }

/*===================================================*\
 * 消息状态2
\*===================================================*/
.king-notice-success.king-notice2 {
  background-color: #e1f4e2 !important;
  padding: 8px;
  border-radius: 6px;
  position: relative; }
  .king-notice-success.king-notice2.king-notice2-large {
    padding: 15px; }
    .king-notice-success.king-notice2.king-notice2-large i {
      font-size: 36px; }
  .king-notice-success.king-notice2 i {
    color: #51be56;
    position: absolute;
    top: 50%;
    margin-top: -9px;
    font-size: 18px; }
  .king-notice-success.king-notice2 .notice-text {
    margin-left: 25px; }
    .king-notice-success.king-notice2 .notice-text h4 {
      font-size: 13px;
      color: #444;
      margin: 0 0 5px 0; }
    .king-notice-success.king-notice2 .notice-text p {
      font-size: 12px;
      color: #666;
      margin-bottom: 0; }
.king-notice-success.notice-borders {
  border: 1px solid #c1e8c3; }

.king-notice-info.king-notice2 {
  background-color: #f2f8ff !important;
  padding: 8px;
  border-radius: 6px;
  position: relative; }
  .king-notice-info.king-notice2.king-notice2-large {
    padding: 15px; }
    .king-notice-info.king-notice2.king-notice2-large i {
      font-size: 36px; }
  .king-notice-info.king-notice2 i {
    color: #5ba4ff;
    position: absolute;
    top: 50%;
    margin-top: -9px;
    font-size: 18px; }
  .king-notice-info.king-notice2 .notice-text {
    margin-left: 25px; }
    .king-notice-info.king-notice2 .notice-text h4 {
      font-size: 13px;
      color: #444;
      margin: 0 0 5px 0; }
    .king-notice-info.king-notice2 .notice-text p {
      font-size: 12px;
      color: #666;
      margin-bottom: 0; }
.king-notice-info.notice-borders {
  border: 1px solid #d1e5ff; }

.king-notice-warning.king-notice2 {
  background-color: #fef7ee !important;
  padding: 8px;
  border-radius: 6px;
  position: relative; }
  .king-notice-warning.king-notice2.king-notice2-large {
    padding: 15px; }
    .king-notice-warning.king-notice2.king-notice2-large i {
      font-size: 36px; }
  .king-notice-warning.king-notice2 i {
    color: #f4bd6e;
    position: absolute;
    top: 50%;
    margin-top: -9px;
    font-size: 18px; }
  .king-notice-warning.king-notice2 .notice-text {
    margin-left: 25px; }
    .king-notice-warning.king-notice2 .notice-text h4 {
      font-size: 13px;
      color: #444;
      margin: 0 0 5px 0; }
    .king-notice-warning.king-notice2 .notice-text p {
      font-size: 12px;
      color: #666;
      margin-bottom: 0; }
.king-notice-warning.notice-borders {
  border: 1px solid #fcebd2; }

.king-notice-danger.king-notice2 {
  background-color: #faeeec !important;
  padding: 8px;
  border-radius: 6px;
  position: relative; }
  .king-notice-danger.king-notice2.king-notice2-large {
    padding: 15px; }
    .king-notice-danger.king-notice2.king-notice2-large i {
      font-size: 36px; }
  .king-notice-danger.king-notice2 i {
    color: #d6776a;
    position: absolute;
    top: 50%;
    margin-top: -9px;
    font-size: 18px; }
  .king-notice-danger.king-notice2 .notice-text {
    margin-left: 25px; }
    .king-notice-danger.king-notice2 .notice-text h4 {
      font-size: 13px;
      color: #444;
      margin: 0 0 5px 0; }
    .king-notice-danger.king-notice2 .notice-text p {
      font-size: 12px;
      color: #666;
      margin-bottom: 0; }
.king-notice-danger.notice-borders {
  border: 1px solid #f2d3cf; }

/*===================================================*\
 * 消息状态3
\*===================================================*/
.king-notice3 {
  text-align: center;
  font-family: "微软雅黑";
  color: #666; }
  .king-notice3 .king-notice-img {
    width: 78px;
    height: 78px;
    display: block;
    margin: 5px auto 20px;
    background: url(../images/notice3-icon.png) no-repeat; }
  .king-notice3 .f12 {
    font-family: "宋体";
    color: #98a1b3; }
  .king-notice3 .king-notice3-color {
    color: #ff7d7d; }
  .king-notice3.king-notice-wating .king-notice-img {
    background-position: 0 0; }
  .king-notice3.king-notice-success .king-notice-img {
    background-position: 0 -78px; }
  .king-notice3.king-notice-fail .king-notice-img {
    background-position: 0 -156px; }

/*===================================================*\ 
 * 异常页面的样式
\*===================================================*/
.king-errorpage-middle {
  position: fixed;
  top: 50%;
  left: 50%;
  margin-top: -185px;
  margin-left: -268px; }
  .king-errorpage-middle .king-exception-box img {
    vertical-align: middle;
    display: inherit;
    margin: 0 auto; }
  .king-errorpage-middle .king-exception-box h1 {
    font-weight: normal;
    line-height: 1.1;
    font-size: 28px;
    margin: 26px 0;
    color: #2b2c2d; }
  .king-errorpage-middle .king-exception-box p {
    font-size: 16px;
    color: #505152; }
  .king-errorpage-middle .king-exception-box .king-403-btn1, .king-errorpage-middle .king-exception-box .king-403-btn2 {
    font-size: 14px; }
  .king-errorpage-middle .king-exception-box .king-403-btn2 {
    background: #5CB85C; }
  .king-errorpage-middle .king-exception-box .king-login-back {
    font-size: 12px; }
    .king-errorpage-middle .king-exception-box .king-login-back span {
      color: #5d9cec; }
    .king-errorpage-middle .king-exception-box .king-login-back a {
      padding: 3px 10px;
      font-size: 14px; }

.king-500-page, .king-401-page, .king-login-page, .king-403-page {
  width: 536px;
  text-align: center;
  margin: auto;
  font-family: STHeiti, "微软雅黑", Arial; }

.king-login-fail {
  width: 536px;
  height: 300px;
  text-align: center;
  margin: auto; }
  .king-login-fail .login-tip {
    margin-top: 20px;
    font-size: 14px; }
    .king-login-fail .login-tip a {
      font-size: 14px;
      margin-left: 10px; }

.king-500-page1 {
  font-family: STHeiti, "微软雅黑", Arial;
  color: #616161; }
  .king-500-page1 .error-number {
    font-size: 100px; }
  .king-500-page1 .error-title {
    font-size: 14px;
    font-weight: bold;
    margin: 15px 0; }
  .king-500-page1 .error-tip {
    font-size: 12px; }
    .king-500-page1 .error-tip a {
      color: #616161;
      display: inline;
      background: none;
      padding: 0;
      margin: 0;
      font-size: 12px; }

.king-nav-tabs1 > li {
  margin-bottom: -2px; }
  .king-nav-tabs1 > li > a {
    border: 1px solid #ddd;
    border-left: none !important;
    margin-right: 0;
    background: #FBFAF8;
    color: #645F63; }
  .king-nav-tabs1 > li:first-child > a {
    border-left: 1px solid #ddd !important; }
  .king-nav-tabs1 > li.active > a {
    background: #FFF; }
    .king-nav-tabs1 > li.active > a:hover {
      border-bottom-color: #fff !important; }
.king-nav-tabs1.nav .open > a, .king-nav-tabs1 .nav .open > a:focus, .king-nav-tabs1 .nav .open > a:hover {
  border-color: #ddd; }
.king-nav-tabs1.nav-tabs > li > a:hover {
  border-color: #ddd; }

.king-tab-success.king-nav-tabs1 > li.active > a {
  border-top: 2px solid #44B549 !important; }

.king-tab-info.king-nav-tabs1 > li.active > a {
  border-top: 2px solid #4A9BFF !important; }

.king-tab-primary.king-nav-tabs1 > li.active > a {
  border-top: 2px solid #5c90d2 !important; }

.king-tab-warning.king-nav-tabs1 > li.active > a {
  border-top: 2px solid #f3b760 !important; }

.king-tab-danger.king-nav-tabs1 > li.active > a {
  border-top: 2px solid #d26a5c !important; }

.king-nav-tabs2 {
  border: 1px solid #ddd;
  background: #FBFAF8; }
  .king-nav-tabs2 > li {
    margin-bottom: -2px; }
    .king-nav-tabs2 > li > a {
      border: none;
      margin-right: 0;
      background: #FBFAF8;
      color: #645F63; }
      .king-nav-tabs2 > li > a:focus {
        background: #FBFAF8; }
    .king-nav-tabs2 > li.active > a {
      border-top: 2px solid #fff !important;
      background: #fff; }
    .king-nav-tabs2 > li.active:first-child a {
      border-left: none; }

.king-tab-success.king-nav-tabs2 > li.active > a {
  margin-top: -1px;
  border-top: 2px solid #44B549 !important; }

.king-tab-info.king-nav-tabs2 > li.active > a {
  margin-top: -1px;
  border-top: 2px solid #4A9BFF !important; }

.king-tab-primary.king-nav-tabs2 > li.active > a {
  margin-top: -1px;
  border-top: 2px solid #5c90d2 !important; }

.king-tab-warning.king-nav-tabs2 > li.active > a {
  margin-top: -1px;
  border-top: 2px solid #f3b760 !important; }

.king-tab-danger.king-nav-tabs2 > li.active > a {
  margin-top: -1px;
  border-top: 2px solid #d26a5c !important; }

/*===================================================*\ 
 * 向前兼容而保留，不要删除
\*===================================================*/
.king-nav-tabs > li {
  margin-bottom: -2px; }
  .king-nav-tabs > li > a {
    border-color: #ddd;
    margin-right: 0;
    background: #FBFAF8;
    color: #645F63; }
  .king-nav-tabs > li.active > a {
    border-top-color: #4A9BFF !important;
    background: #FFF;
    border-top-width: 2px !important; }
    .king-nav-tabs > li.active > a:focus {
      border-top-color: #4A9BFF !important;
      background: #FFF;
      border-top-width: 2px !important; }

.JColResizer.table th, .JColResizer.table td {
  overflow: hidden;
  padding-left: 8px !important;
  padding-right: 8px !important; }

.JCLRgripDrag {
  border: 0 !important; }

/*===================================================*\
 * instructions
\*===================================================*/
.king-instruction {
  font-size: 12px;
  line-height: 20px;
  overflow: hidden;
  padding: 10px 20px;
  cursor: default; }
  .king-instruction span {
    color: red; }
  .king-instruction h5 {
    font-weight: 700;
    font-size: 12px;
    margin: 0px;
    line-height: 20px; }
  .king-instruction p {
    margin: 0;
    padding: 0;
    line-height: 20px; }
  .king-instruction.king-instruction-info {
    color: #177fff;
    border: #b0d3ff 1px solid;
    background: #e3f0ff; }
  .king-instruction.king-instruction-primary {
    color: #3675c5;
    border: #acc6e8 1px solid;
    background-color: #d4e2f3; }
  .king-instruction.king-instruction-warning {
    color: #efa231;
    border: #fae2bf 1px solid;
    background-color: #fef7ee; }
  .king-instruction.king-instruction-danger {
    color: #c54736;
    border: #e8b3ac 1px solid;
    background-color: #f3d8d4; }
  .king-instruction.king-instruction-success {
    color: #36903a;
    border: #b0e2b3 1px solid;
    background-color: #e8f6e9; }

/*===================================================*\
 * 表单
\*===================================================*/
.king-table7-demo3 .king-input-group {
  width: 260px; }
.king-table7-demo3 .king-btn-new {
  background: #5c90d2;
  border-color: #3675c5;
  color: #fff; }
.king-table7-demo3 .king-form-control-feedback {
  width: 30px;
  height: 30px;
  left: 0;
  line-height: 30px;
  color: #999; }
.king-table7-demo3 .table .king-btn {
  width: 70px;
  height: 24px;
  padding: 0;
  min-width: 70px; }

/*===================================================*\ 
 * 常见问题 template6
\*===================================================*/
.king-page-problem {
  padding-bottom: 30px; }
  .king-page-problem section {
    padding-top: 30px; }
    .king-page-problem section h2 {
      min-height: 25px;
      margin: 0;
      font-size: 16px;
      font-weight: bold;
      line-height: 25px; }
    .king-page-problem section > div {
      padding: 13px 25px 8px 13px;
      margin-top: 10px;
      border: 1px solid #e3e3e3;
      background: #f5f5f5;
      position: relative; }
      .king-page-problem section > div::after {
        display: block;
        content: "";
        width: 17px;
        height: 11px;
        position: absolute;
        top: -11px;
        left: 32px; }
    .king-page-problem section p {
      font-size: 13px;
      line-height: 24px; }

/*===================================================*\ 
 * 提示信息 template3
\*===================================================*/
.king-help-block {
  color: #737373;
  display: block;
  margin-bottom: 10px;
  margin-top: 5px;
  font-size: 12px; }

/*===================================================*\ 
 * 进度条 progress1
\*===================================================*/
.king-progress {
  height: 8px;
  border-radius: 0; }
  .king-progress .progress-bar {
    border-radius: 0; }

/*===================================================*\ 
 * 版权声明 template5                                         
\*===================================================*/
.king-copyright {
  text-align: center;
  padding: 30px;
  color: #666;
  font-size: 13px; }

/*===================================================*\ 
 * bootstrap popover插件样式修复
\*===================================================*/
.king-block .popover-title {
  padding: 8px 14px; }

.king-loading {
  z-index: 9999;
  position: fixed;
  background: #000;
  width: 50px;
  height: 50px;
  text-align: center;
  line-height: 46px;
  left: 0;
  right: 0;
  bottom: 0;
  top: 0;
  margin: auto;
  border-radius: 6px; }

.ui-autocomplete-category {
  line-height: 24px;
  padding: 5px 10px;
  font-weight: bold;
  background: #fafafa; }

.king-jquery-ui-item {
  padding: 5px 10px; }

.king-autocomplete-loading {
  background: white url(../images/loading_2_16x16.gif) right center no-repeat; }

.king-tab-content {
  border: 1px solid #ddd;
  margin: -1px;
  background: #fff; }

.magic-desc {
  font-size: 14px;
  margin: 15px 0 10px 0; }

.magic-desc .strong {
  font-weight: bold;
  color: #F97A49; }

/*===================================================*\ 
 * bk pc端样式
\*===================================================*/
html, body {
  height: 100%; }

body {
  font-family: STHeiti,'Microsoft Yahei'; }

ul {
  list-style: none; }

h1, h2, h3, h4, h5, h6 {
  outline: none; }

button, a {
  outline: none; }

a:hover, a:active, a:focus {
  text-decoration: none;
  outline: none; }

/*===================================================*\ 
 * bootsrtap样式重置
\*===================================================*/
.form-control {
  border-radius: 0;
  font-size: 12px;
  height: 30px;
  padding: 5px; }

label {
  font-weight: normal; }

.btn {
  border-radius: 0; }

.btn-info {
  background-color: #4797E7;
  border-color: #0E7AE2; }

.input-group-addon {
  border-radius: 0; }

.form-control {
  box-shadow: none; }

.form-control:focus {
  box-shadow: none; }

.progress {
  margin-bottom: 0;
  box-shadow: none;
  border-radius: 0; }

.pagination > .active > a, .pagination > .active > span, .pagination > .active > a:hover, .pagination > .active > span:hover, .pagination > .active > a:focus, .pagination > .active > span:focus {
  background-color: #4A9BFF;
  border-color: #2180F5; }

.table-bordered > thead > tr > th, .table-bordered > thead > tr > td {
  border-bottom-width: 1px; }

.table-header-bg th {
  background: #f6f8f8; }

.table-out-bordered th {
  border-top: 2px solid #2180F5 !important; }

.validate-form .error {
  color: #a94442; }

.pagination > li:first-child > a, .pagination > li:first-child > span {
  border-radius: 0; }

.pagination > li:last-child > a, .pagination > li:last-child > span {
  border-radius: 0; }

.table tfoot td {
  background: #fafafa; }

.table tfoot .pagination {
  margin: 0; }

.table tfoot .pagination-info {
  margin: 7px 15px 0 0; }

.pagination-small > li > a, .pagination-small > li > span {
  padding: 4px 10px; }

.nav-tabs > li > a {
  border-radius: 0; }

.modal-content {
  -webkit-box-shadow: none;
  box-shadow: none;
  -webkit-border-radius: 0;
  border-radius: 0; }

.alert {
  border-radius: 0; }

.dropdown-menu {
  border-radius: 0; }

.breadcrumb, .thumbnail {
  border-radius: 0; }

.table {
  background: #fff; }

.table > tbody > tr > td, .table > tbody > tr > th, .table > tfoot > tr > td, .table > tfoot > tr > th, .table > thead > tr > td, .table > thead > tr > th {
  vertical-align: middle; }

.dataTables_paginate .pagination > li > a, .dataTables_paginate .pagination > li > span {
  line-height: 16px;
  padding: 5px 10px; }

.input-group-addon {
  padding: 5px 10px; }

.form-control {
  display: inline-block; }

label {
  max-width: none; }

.badge {
  font-weight: normal;
  background: #4A9BFF; }

.form-group .help-block {
  margin-bottom: 0; }

.panel {
  border-radius: 0; }

.tab-content {
  border-left: 1px solid #ddd;
  border-right: 1px solid #ddd;
  border-bottom: 1px solid #ddd; }

/*===================================================*\ 
 * bootsrtap样式重置
\*===================================================*/
.k-grid, .k-scheduler, .k-menu, .k-editor {
  border-radius: 0; }

.k-widget, .k-button {
  box-shadow: none; }

/*===================================================*\ 
 * 自定义fieldset样式
\*===================================================*/
.fieldset {
  border: 1px solid #ddd;
  padding: 30px 15px;
  position: relative; }

.legend {
  margin-top: -1.2em;
  font-size: 14px;
  position: absolute;
  top: .5em;
  background: white;
  padding: 0 10px;
  margin-left: -10px; }

/*===================================================*\ 
 * jPage 插件样式
\*===================================================*/
.king-jP {
  margin: 15px 0; }

.king-jP a {
  font-size: 12px;
  cursor: pointer;
  margin-left: -1px;
  border: 1px solid #ddd;
  line-height: 16px;
  padding: 5px 10px; }

.king-jP a:hover {
  background-color: #f0f0f0; }

.king-jP a.jp-current, .king-jP a.jp-current:hover {
  background: #4A9BFF;
  color: #fff;
  border-color: #4A9BFF; }

.king-jP a.jp-disabled, .king-jP a.jp-disabled:hover {
  color: #bbb; }

.king-jP a.jp-current, .king-jP a.jp-current:hover, .king-jP a.jp-disabled, .king-jP a.jp-disabled:hover {
  cursor: default; }

.king-jP span {
  margin: 0 5px; }

/*===================================================*\ 
 * jqueryUI 样式覆盖
\*===================================================*/
.ui-corner-all, .ui-corner-top, .ui-corner-right, .ui-corner-tr {
  border-radius: 0 !important; }

.ui-corner-all, .ui-corner-bottom, .ui-corner-left, .ui-corner-bl {
  border-radius: 0 !important; }

.ui-state-default, .ui-widget-content .ui-state-default, .ui-widget-header .ui-state-default {
  background: #F8F8F8 !important; }

.ui-widget-content {
  border-color: #ddd !important; }

.ui-state-active, .ui-widget-content .ui-state-active, .ui-widget-header .ui-state-active {
  border-color: #ddd !important; }

.ui-accordion .ui-accordion-content {
  padding: 15px !important; }

.king-no-margin {
  margin: 0 !important; }

/*===================================================*\ 
 * 重写kendoUI的树形表样式
\*===================================================*/
.k-treeview .k-state-selected, .k-treeview .k-state-selected:link, .k-treeview .k-state-selected:visited, .k-treeview .k-list > .k-state-selected {
  background-color: #b8b8b8;
  color: #000; }

.k-treeview .k-in {
  border-radius: 0;
  box-shadow: none; }

.dataTables_empty {
  text-align: center;
  padding: 15px !important; }

/*===================================================*\
 * 字体大小
\*===================================================*/
.f10 {
  font-size: 10px !important; }

.f11 {
  font-size: 11px !important; }

.f12 {
  font-size: 12px !important; }

.f13 {
  font-size: 13px !important; }

.f14 {
  font-size: 14px !important; }

.f15 {
  font-size: 15px !important; }

.f16 {
  font-size: 16px !important; }

.f17 {
  font-size: 17px !important; }

.f18 {
  font-size: 18px !important; }

.f19 {
  font-size: 19px !important; }

.f20 {
  font-size: 20px !important; }

.f21 {
  font-size: 21px !important; }

.f22 {
  font-size: 22px !important; }

.f23 {
  font-size: 23px !important; }

.f24 {
  font-size: 24px !important; }

.f25 {
  font-size: 25px !important; }

.f26 {
  font-size: 26px !important; }

.f27 {
  font-size: 27px !important; }

.f28 {
  font-size: 28px !important; }

.f29 {
  font-size: 29px !important; }

.f30 {
  font-size: 30px !important; }

.f31 {
  font-size: 31px !important; }

.f32 {
  font-size: 32px !important; }

.f33 {
  font-size: 33px !important; }

.f34 {
  font-size: 34px !important; }

.f35 {
  font-size: 35px !important; }

.f36 {
  font-size: 36px !important; }

.f37 {
  font-size: 37px !important; }

.f38 {
  font-size: 38px !important; }

.f39 {
  font-size: 39px !important; }

.f40 {
  font-size: 40px !important; }

/*===================================================*\
 * 宽度值
\*===================================================*/
.w {
  width: 100% !important; }

.w10 {
  width: 10px !important; }

.w20 {
  width: 20px !important; }

.w30 {
  width: 30px !important; }

.w40 {
  width: 40px !important; }

.w50 {
  width: 50px !important; }

.w60 {
  width: 60px !important; }

.w70 {
  width: 70px !important; }

.w80 {
  width: 80px !important; }

.w90 {
  width: 90px !important; }

.w100 {
  width: 100px !important; }

.w200 {
  width: 200px !important; }

.w300 {
  width: 300px !important; }

.w400 {
  width: 400px !important; }

.w500 {
  width: 500px !important; }

.w600 {
  width: 600px !important; }

.w700 {
  width: 700px !important; }

.w800 {
  width: 800px !important; }

/*===================================================*\
 * margin 和 padding什
\*===================================================*/
.m0 {
  margin: 0px !important; }

.m5 {
  margin: 5px !important; }

.m10 {
  margin: 10px !important; }

.m15 {
  margin: 15px !important; }

.m20 {
  margin: 20px !important; }

.m25 {
  margin: 25px !important; }

.m30 {
  margin: 30px !important; }

.m35 {
  margin: 35px !important; }

.m40 {
  margin: 40px !important; }

.m45 {
  margin: 45px !important; }

.m50 {
  margin: 50px !important; }

.mt0 {
  margin-top: 0px !important; }

.mt5 {
  margin-top: 5px !important; }

.mt10 {
  margin-top: 10px !important; }

.mt15 {
  margin-top: 15px !important; }

.mt20 {
  margin-top: 20px !important; }

.mt25 {
  margin-top: 25px !important; }

.mt30 {
  margin-top: 30px !important; }

.mt35 {
  margin-top: 35px !important; }

.mt40 {
  margin-top: 40px !important; }

.mt45 {
  margin-top: 45px !important; }

.mt50 {
  margin-top: 50px !important; }

.mb0 {
  margin-bottom: 0px !important; }

.mb5 {
  margin-bottom: 5px !important; }

.mb10 {
  margin-bottom: 10px !important; }

.mb15 {
  margin-bottom: 15px !important; }

.mb20 {
  margin-bottom: 20px !important; }

.mb25 {
  margin-bottom: 25px !important; }

.mb30 {
  margin-bottom: 30px !important; }

.mb35 {
  margin-bottom: 35px !important; }

.mb40 {
  margin-bottom: 40px !important; }

.mb45 {
  margin-bottom: 45px !important; }

.mb50 {
  margin-bottom: 50px !important; }

.ml0 {
  margin-left: 0px !important; }

.ml5 {
  margin-left: 5px !important; }

.ml10 {
  margin-left: 10px !important; }

.ml15 {
  margin-left: 15px !important; }

.ml20 {
  margin-left: 20px !important; }

.ml25 {
  margin-left: 25px !important; }

.ml30 {
  margin-left: 30px !important; }

.ml35 {
  margin-left: 35px !important; }

.ml40 {
  margin-left: 40px !important; }

.ml45 {
  margin-left: 45px !important; }

.ml50 {
  margin-left: 50px !important; }

.mr0 {
  margin-right: 0px !important; }

.mr5 {
  margin-right: 5px !important; }

.mr10 {
  margin-right: 10px !important; }

.mr15 {
  margin-right: 15px !important; }

.mr20 {
  margin-right: 20px !important; }

.mr25 {
  margin-right: 25px !important; }

.mr30 {
  margin-right: 30px !important; }

.mr35 {
  margin-right: 35px !important; }

.mr40 {
  margin-right: 40px !important; }

.mr45 {
  margin-right: 45px !important; }

.mr50 {
  margin-right: 50px !important; }

.p0 {
  padding: 0px !important; }

.p5 {
  padding: 5px !important; }

.p10 {
  padding: 10px !important; }

.p15 {
  padding: 15px !important; }

.p20 {
  padding: 20px !important; }

.p25 {
  padding: 25px !important; }

.p30 {
  padding: 30px !important; }

.p35 {
  padding: 35px !important; }

.p40 {
  padding: 40px !important; }

.p45 {
  padding: 45px !important; }

.p50 {
  padding: 50px !important; }

.pt0 {
  padding-top: 0px !important; }

.pt5 {
  padding-top: 5px !important; }

.pt10 {
  padding-top: 10px !important; }

.pt15 {
  padding-top: 15px !important; }

.pt20 {
  padding-top: 20px !important; }

.pt25 {
  padding-top: 25px !important; }

.pt30 {
  padding-top: 30px !important; }

.pt35 {
  padding-top: 35px !important; }

.pt40 {
  padding-top: 40px !important; }

.pt45 {
  padding-top: 45px !important; }

.pt50 {
  padding-top: 50px !important; }

.pb0 {
  padding-bottom: 0px !important; }

.pb5 {
  padding-bottom: 5px !important; }

.pb10 {
  padding-bottom: 10px !important; }

.pb15 {
  padding-bottom: 15px !important; }

.pb20 {
  padding-bottom: 20px !important; }

.pb25 {
  padding-bottom: 25px !important; }

.pb30 {
  padding-bottom: 30px !important; }

.pb35 {
  padding-bottom: 35px !important; }

.pb40 {
  padding-bottom: 40px !important; }

.pb45 {
  padding-bottom: 45px !important; }

.pb50 {
  padding-bottom: 50px !important; }

.pl0 {
  padding-left: 0px !important; }

.pl5 {
  padding-left: 5px !important; }

.pl10 {
  padding-left: 10px !important; }

.pl15 {
  padding-left: 15px !important; }

.pl20 {
  padding-left: 20px !important; }

.pl25 {
  padding-left: 25px !important; }

.pl30 {
  padding-left: 30px !important; }

.pl35 {
  padding-left: 35px !important; }

.pl40 {
  padding-left: 40px !important; }

.pl45 {
  padding-left: 45px !important; }

.pl50 {
  padding-left: 50px !important; }

.pr0 {
  padding-right: 0px !important; }

.pr5 {
  padding-right: 5px !important; }

.pr10 {
  padding-right: 10px !important; }

.pr15 {
  padding-right: 15px !important; }

.pr20 {
  padding-right: 20px !important; }

.pr25 {
  padding-right: 25px !important; }

.pr30 {
  padding-right: 30px !important; }

.pr35 {
  padding-right: 35px !important; }

.pr40 {
  padding-right: 40px !important; }

.pr45 {
  padding-right: 45px !important; }

.pr50 {
  padding-right: 50px !important; }

/*===================================================*\
 * 基础色值
\*===================================================*/
.king-default {
  background-color: #f4f4f4; }

.king-bg-default {
  background-color: #f4f4f4; }

a.king-default:hover {
  background-color: #dbdbdb; }

.bg-default {
  background-color: #f4f4f4; }

.color-default {
  color: #f4f4f4; }

.text-default {
  color: #f4f4f4; }
  .text-default:hover {
    color: #f4f4f4 !important; }

.king-gray {
  background-color: #555; }

.king-bg-gray {
  background-color: #555; }

a.king-gray:hover {
  background-color: #3c3c3c; }

.bg-gray {
  background-color: #555; }

.color-gray {
  color: #555; }

.text-gray {
  color: #555; }
  .text-gray:hover {
    color: #555 !important; }

.king-info {
  background-color: #4A9BFF; }

.king-bg-info {
  background-color: #4A9BFF; }

a.king-info:hover {
  background-color: #177fff; }

.bg-info {
  background-color: #4A9BFF; }

.color-info {
  color: #4A9BFF; }

.text-info {
  color: #4A9BFF; }
  .text-info:hover {
    color: #4A9BFF !important; }

.king-primary {
  background-color: #5c90d2; }

.king-bg-primary {
  background-color: #5c90d2; }

a.king-primary:hover {
  background-color: #3675c5; }

.bg-primary {
  background-color: #5c90d2; }

.color-primary {
  color: #5c90d2; }

.text-primary {
  color: #5c90d2; }
  .text-primary:hover {
    color: #5c90d2 !important; }

.king-danger {
  background-color: #d26a5c; }

.king-bg-danger {
  background-color: #d26a5c; }

a.king-danger:hover {
  background-color: #c54736; }

.bg-danger {
  background-color: #d26a5c; }

.color-danger {
  color: #d26a5c; }

.text-danger {
  color: #d26a5c; }
  .text-danger:hover {
    color: #d26a5c !important; }

.king-warning {
  background-color: #f3b760; }

.king-bg-warning {
  background-color: #f3b760; }

a.king-warning:hover {
  background-color: #efa231; }

.bg-warning {
  background-color: #f3b760; }

.color-warning {
  color: #f3b760; }

.text-warning {
  color: #f3b760; }
  .text-warning:hover {
    color: #f3b760 !important; }

.king-success {
  background-color: #44B549; }

.king-bg-success {
  background-color: #44B549; }

a.king-success:hover {
  background-color: #36903a; }

.bg-success {
  background-color: #44B549; }

.color-success {
  color: #44B549; }

.text-success {
  color: #44B549; }
  .text-success:hover {
    color: #44B549 !important; }

.king-muted {
  background-color: #999; }

.king-bg-muted {
  background-color: #999; }

a.king-muted:hover {
  background-color: gray; }

.bg-muted {
  background-color: #999; }

.color-muted {
  color: #999; }

.text-muted {
  color: #999; }
  .text-muted:hover {
    color: #999 !important; }

.king-dark {
  background-color: #333; }

.king-bg-dark {
  background-color: #333; }

a.king-dark:hover {
  background-color: #1a1a1a; }

.bg-dark {
  background-color: #333; }

.color-dark {
  color: #333; }

.text-dark {
  color: #333; }
  .text-dark:hover {
    color: #333 !important; }

/*===================================================*\
 * 辅助样式
\*===================================================*/
.color-info-alt {
  color: #669; }

.color-reverse {
  color: #fff; }

.color-gray-darker {
  color: #222; }

.color-gray-dark {
  color: #333; }

.color-gray-light {
  color: #777; }

.color-gray-lighter {
  color: #eee; }

.king-bg-gray {
  background-color: #f4f4f4 !important; }

.king-bg-blue {
  background-color: #4A9BFF !important; }

.king-bg-darkblue {
  background-color: #5c90d2 !important; }

.king-bg-green {
  background-color: #46c37b !important; }

.king-bg-yellow {
  background-color: #f3b760 !important; }

.king-bg-red {
  background-color: #d26a5c !important; }

.king-bg-aqua {
  background-color: #00c0ef !important; }

.king-primary-op {
  background-color: rgba(92, 144, 210, 0.75); }

a.king-primary-op:hover {
  background-color: rgba(54, 117, 197, 0.75); }

.king-primary-dark {
  background-color: #3e4a59; }

a.king-primary-dark:hover {
  background-color: #29313b; }

.king-primary-dark-op {
  background-color: rgba(62, 74, 89, 0.83); }

a.king-primary-dark-op:hover {
  background-color: rgba(41, 49, 59, 0.83); }

.king-primary-darker {
  background-color: #2c343f; }

a.king-primary-darker:hover {
  background-color: #171b21; }

.king-primary-light {
  background-color: #98b9e3; }

a.king-primary-light:hover {
  background-color: #709ed8; }

.king-primary-lighter {
  background-color: #ccdcf1; }

a.king-primary-lighter:hover {
  background-color: #a4c1e6; }

.king-success-light {
  background-color: #e0f5e9; }

a.king-success-light:hover {
  background-color: #b9e9ce; }

.king-warning-light {
  background-color: #fdf3e5; }

a.king-warning-light:hover {
  background-color: #f9ddb6; }

.king-info-light {
  background-color: #edf6fd; }

a.king-info-light:hover {
  background-color: #bfdff8; }

.king-danger-light {
  background-color: #f9eae8; }

a.king-danger-light:hover {
  background-color: #eec5c0; }

.king-white {
  background-color: #fff; }

a.king-white:hover {
  background-color: #e6e6e6; }

.king-white-op {
  background-color: rgba(255, 255, 255, 0.075); }

.king-black {
  background-color: #000; }

a.king-black:hover {
  background-color: #000; }

.king-black-op {
  background-color: rgba(0, 0, 0, 0.4); }

.king-gray-dark {
  background-color: #999; }

a.king-gray-dark:hover {
  background-color: #808080; }

.king-gray-darker {
  background-color: #393939; }

a.king-gray-darker:hover {
  background-color: #202020; }

.king-gray-light {
  background-color: #f3f3f3; }

a.king-gray-light:hover {
  background-color: #dadada; }

.king-gray-lighter {
  background-color: #f9f9f9; }

a.king-gray-lighter:hover {
  background-color: #e0e0e0; }

.fb {
  font-weight: bold !important; }

.fn {
  font-weight: normal !important; }

.lh150 {
  line-height: 150% !important; }

.lh180 {
  line-height: 180% !important; }

.lh200 {
  line-height: 200% !important; }

.unl {
  text-decoration: underline !important; }

.no_unl {
  text-decoration: none !important; }

.tl {
  text-align: left !important; }

.tc {
  text-align: center !important; }

.tr {
  text-align: right !important; }

.bc {
  margin-left: auto !important;
  margin-right: auto !important; }

.fl {
  float: left !important; }

.fr {
  float: right !important; }

.cb {
  clear: both !important; }

.cl {
  clear: left !important; }

.cr {
  clear: right !important; }

.clearfix:after {
  content: '.';
  display: block;
  height: 0;
  clear: both;
  visibility: hidden; }

.clearfix {
  display: inline-block; }

.clearfix {
  display: block;
  zoom: 1; }

.vm {
  vertical-align: middle !important; }

.pr {
  position: relative !important; }

.pa {
  position: absolute !important; }

.abs-right {
  position: absolute !important; }

.zoom {
  zoom: 1; }

.hidden {
  visibility: hidden !important; }

.none {
  display: none !important; }

.h50 {
  height: 50px !important; }

.h80 {
  height: 80px !important; }

.h100 {
  height: 100px !important; }

.h200 {
  height: 200px !important; }

.h {
  height: 100% !important; }

.text-explode {
  color: #ccc !important; }

.text-white {
  color: white !important; }

.color-info-alt {
  color: #669; }

.color-reverse {
  color: #fff; }

.color-gray-darker {
  color: #222; }

.color-gray-dark {
  color: #333; }

.color-gray-light {
  color: #777; }

.color-gray-lighter {
  color: #eee; }

a.bg-white, a.bg-white:hover {
  background-color: #fff !important;
  color: #444 !important; }

a.bg-primary, a.bg-primary:hover {
  background-color: #5C90D2 !important;
  color: #fff !important; }

a.bg-success, a.bg-success:hover {
  background-color: #46C37B !important;
  color: #fff !important; }

a.bg-info, a.bg-info:hover {
  background-color: #4A9BFF !important;
  color: #fff !important; }

a.bg-warning, a.bg-warning:hover {
  background-color: #f0a63a !important;
  color: #fff !important; }

a.bg-danger, a.bg-danger:hover {
  background-color: #c94d3c !important;
  color: #fff !important; }

a.bg-orange, a.bg-orange:hover {
  background-color: #EF9549 !important;
  color: #fff !important; }

.bg-white {
  background-color: #fff !important;
  color: #444 !important; }

.bg-bright1 {
  background-color: #fafafa !important;
  color: #767676 !important; }

.bg-bright2 {
  background-color: #f5f5f5 !important;
  color: #767676 !important; }

.bg-bright3 {
  background-color: #eee !important;
  color: #444 !important; }

.bg-bright4 {
  background-color: #ddd !important;
  color: #444 !important; }

.bg-bright5 {
  background-color: #999 !important;
  color: #444 !important; }

.bg-primary {
  background-color: #5C90D2 !important;
  color: #fff !important; }

.bg-primary-light {
  background-color: #40DEC8 !important;
  color: #fff !important; }

.bg-success {
  background-color: #46C37B !important;
  color: #fff !important; }

.bg-info {
  background-color: #4A9BFF !important;
  color: #fff !important; }

.bg-warning {
  background-color: #f0a63a !important;
  color: #fff !important; }

.bg-danger {
  background-color: #c94d3c !important;
  color: #fff !important; }

.bg-orange {
  background-color: #EF9549 !important;
  color: #fff !important; }

.bg-violet {
  background-color: #669 !important;
  color: #fff !important; }

.bg-dark {
  background-color: #242633 !important;
  color: #fff !important; }

.bg-reverse {
  background-color: #fff !important;
  color: #767676 !important; }

img.img30_30 {
  width: 30px;
  height: 30px; }

img.img64_64 {
  width: 64px;
  height: 64px; }

img.img80_80 {
  width: 80px;
  height: 80px; }

.text-small {
  font-size: 12px; }

.text-normal {
  font-size: 14px; }

.text-huge {
  font-size: 72px; }

.text-large {
  font-size: 50px; }

.size-h1 {
  font-size: 36px; }

.size-h2 {
  font-size: 30px; }

.size-h3 {
  font-size: 24px; }

.size-h4 {
  font-size: 18px; }

.text-thin {
  font-weight: 300; }

.text-ultralight {
  font-weight: 100; }

.divider {
  display: block;
  height: 10px; }

.divider-sm {
  height: 15px; }

.divider-md {
  height: 20px; }

.divider-lg {
  height: 30px; }

.divider-xl {
  height: 50px; }

.space {
  display: inline;
  padding: 5px; }

.space-md {
  padding: 15px; }

.space-lg {
  padding: 25px; }

.bordered {
  border: 1px solid #ddd; }

/* 表单样式因字体大小改变导致的错乱修复 start */
.bk-lh30 {
  line-height: 30px; }

.bk-h30 {
  height: 30px; }

.bk-valign-top {
  vertical-align: top; }

.bk-top5 {
  top: 5px; }

button.king-btn.bk-mt3 {
  margin-top: 3px; }

button.king-btn.bk-block {
  display: block; }

/* 表单样式因字体大小改变导致的错乱修复 end */

/*# sourceMappingURL=bk.css.map */
